@@ -28,7 +28,10 @@
 #include <QComboBox>
 #include <QDesktopWidget>
 #include <QFile>
+#include <QFrame>
+#include <QLabel>
 #include <QPixmap>
+#include <QSizePolicy>
 #include <QStringList>
 #include <QTextStream>
 
@@ -81,11 +84,6 @@
  */
 #define CASE_COMMAND(x) } else if (parser.command() == x) {
 
-
-#define STATUS_ID_SIZE     1 /**< index of status item for size [samples,ms]*/
-#define STATUS_ID_MODE     2 /**< index of status item for mode */
-#define STATUS_ID_SELECTED 3 /**< index of status item for selection */
-
 //***************************************************************************
 KToolBar *TopWidget::toolBar(const QString &name)
 {
@@ -104,7 +102,8 @@ TopWidget::TopWidget(KwaveApp &main_app)
      m_blink_on(false), m_action_undo(0), m_action_redo(0), m_action_play(0),
      m_action_loop(0), m_action_pause(0),m_action_stop(0),
      m_action_zoomselection(0), m_action_zoomin(0), m_action_zoomout(0),
-     m_action_zoomnormal(0), m_action_zoomall(0), m_action_zoomselect(0)
+     m_action_zoomnormal(0), m_action_zoomall(0), m_action_zoomselect(0),
+     m_lbl_status_size(0), m_lbl_status_mode(0), m_lbl_status_cursor(0)
 {
     KIconLoader icon_loader;
 
@@ -119,13 +118,39 @@ TopWidget::TopWidget(KwaveApp &main_app)
     // connect clicked menu entries with main communication channel of kwave
     connect(m_menu_manager, SIGNAL(sigMenuCommand(const QString &)),
 	    this, SLOT(executeCommand(const QString &)));
+    connect(&ClipBoard::instance(), SIGNAL(clipboardChanged(bool)),
+	    this, SLOT(clipboardChanged(bool)));
 
+    // status bar items
     KStatusBar *status_bar = statusBar();
     Q_ASSERT(status_bar);
     if (!status_bar) return;
-    status_bar->insertItem("", STATUS_ID_SIZE);
-    status_bar->insertItem("", STATUS_ID_MODE);
-    status_bar->insertItem("", STATUS_ID_SELECTED);
+
+    QLabel *spacer = new QLabel(this);
+    const int frame_style = QFrame::StyledPanel | QFrame::Sunken;
+    status_bar->addWidget(spacer);
+    spacer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
+    spacer->setFrameStyle(frame_style);
+    QSizePolicy policy = spacer->sizePolicy();
+    policy.setHorizontalStretch(100);
+    spacer->setSizePolicy(policy);
+    policy.setHorizontalStretch(0);
+
+    m_lbl_status_cursor = new QLabel(this);
+    status_bar->addWidget(m_lbl_status_cursor);
+    m_lbl_status_cursor->setSizePolicy(policy);
+    m_lbl_status_cursor->setFrameStyle(frame_style);
+
+    m_lbl_status_mode = new QLabel(this);
+    status_bar->addWidget(m_lbl_status_mode);
+    m_lbl_status_mode->setSizePolicy(policy);
+    m_lbl_status_mode->setFrameStyle(frame_style);
+
+    m_lbl_status_size = new QLabel(this);
+    status_bar->addWidget(m_lbl_status_size);
+    m_lbl_status_size->setSizePolicy(policy);
+    m_lbl_status_size->setFrameStyle(frame_style);
+
     setStatusInfo(SAMPLE_MAX,99,196000,24); // affects the menu !
 
     // load the menu from file
@@ -157,6 +182,9 @@ TopWidget::TopWidget(KwaveApp &main_app)
             this, SLOT(setTrackInfo(unsigned int)));
     connect(m_main_widget, SIGNAL(sigMouseChanged(int)),
             this, SLOT(mouseChanged(int)));
+    connect(&m_main_widget->playbackController(),
+            SIGNAL(sigPlaybackPos(unsigned int)),
+            this, SLOT(updatePlaybackPos(unsigned int)));
 
     // connect the sigCommand signal to ourself, this is needed
     // for the plugins
@@ -213,10 +241,13 @@ TopWidget::TopWidget(KwaveApp &main_app)
 	i18n("copy the current selection to the clipboard"),
 	this, SLOT(toolbarEditCopy()));
 
-    toolbar_edit->addAction(
+    QAction *btPaste = toolbar_edit->addAction(
 	icon_loader.loadIcon("edit-paste", KIconLoader::Toolbar),
 	i18n("insert the content of clipboard"),
 	this, SLOT(toolbarEditPaste()));
+    btPaste->setEnabled(!ClipBoard::instance().isEmpty());
+    connect(&ClipBoard::instance(), SIGNAL(clipboardChanged(bool)),
+            btPaste, SLOT(setEnabled(bool)));
 
     toolbar_edit->addAction(
 	icon_loader.loadIcon("draw-eraser", KIconLoader::Toolbar),
@@ -516,6 +547,9 @@ int TopWidget::executeCommand(const QString &line)
     // parse one single command
     Parser parser(command);
 
+    // exclude menu commands from the recorder
+    if (parser.command() == "menu") use_recorder = false;
+
     // playback commands are always possible
     if (parser.command() == "playback") {
 	return executePlaybackCommand(parser.firstParam()) ? 0 : -1;
@@ -528,6 +562,12 @@ int TopWidget::executeCommand(const QString &line)
 	return false;
     }
 
+    if (use_recorder) {
+	// append the command to the macro recorder
+	// @TODO macro recording...
+	qDebug("TopWidget::executeCommand(%s)", command.toLocal8Bit().data()); // ###
+    }
+
     if (m_app.executeCommand(command)) {
 	return 0;
     CASE_COMMAND("about_kde")
@@ -609,11 +649,6 @@ int TopWidget::executeCommand(const QString &line)
 	    m_main_widget->executeCommand(command)) ? 0 : -1;
     }
 
-    if (use_recorder) {
-	// append the command to the macro recorder
-        // @TODO macro recording...
-    }
-
     return result;
 }
 
@@ -669,7 +704,6 @@ int TopWidget::parseCommands(QTextStream &stream)
 int TopWidget::revert()
 {
     KUrl url(signalName());
-    Q_ASSERT(url.isValid());
     if (!url.isValid()) return -EINVAL;
 
     return loadFile(url);
@@ -723,7 +757,6 @@ int TopWidget::loadFile(const KUrl &url)
     if (!m_main_widget) return -1;
 
     // abort if new file not valid and local
-    Q_ASSERT(url.isLocalFile());
     if (!url.isLocalFile()) return -1;
 
     // try to close the previous file
@@ -734,6 +767,9 @@ int TopWidget::loadFile(const KUrl &url)
     if (!m_main_widget->loadFile(url)) {
 	// succeeded
 	updateCaption();
+
+	// enable revert after successful load
+	m_menu_manager->setItemEnabled("ID_FILE_REVERT", true);
     } else {
 	// load failed
 	closeFile();
@@ -786,6 +822,9 @@ int TopWidget::saveFile()
     updateCaption();
     updateMenu();
 
+    // enable "revert" after successful "save"
+    if (!res) m_menu_manager->setItemEnabled("ID_FILE_REVERT", true);
+
     return res;
 }
 
@@ -876,6 +915,12 @@ int TopWidget::saveFileAs(bool selection)
     m_app.addRecentFile(signalName());
     updateMenu();
 
+    if (!res && !selection) {
+	// enable "revert" after successful "save as"
+	// of the whole file (not only selection)
+	m_menu_manager->setItemEnabled("ID_FILE_REVERT", true);
+    }
+
     return res;
 }
 
@@ -923,7 +968,8 @@ void TopWidget::selectZoom(int index)
     unsigned int width = m_main_widget->displayWidth();
     Q_ASSERT(width > 1);
     if (width <= 1) width = 2;
-    const double new_zoom = rint(((rate*ms)/1E3)-1) / (double)(width-1);
+    const double new_zoom = rint(((rate * ms) / 1E3) -1 ) /
+	static_cast<double>(width - 1);
     m_main_widget->setZoom(new_zoom);
 
     // force the zoom factor to be set, maybe the current selection
@@ -946,23 +992,24 @@ void TopWidget::setZoomInfo(double zoom)
 	double rate = signalManager().rate();
 	if (rate > 0) {
 	    // time display mode
-	    double ms = m_main_widget->displaySamples()*1E3/(double)rate;
-	    int s = (int)floor(ms / 1000.0);
-	    int m = (int)floor(s / 60.0);
+	    double ms = m_main_widget->displaySamples() * 1E3 / rate;
+	    int s = static_cast<int>(floor(ms / 1000.0));
+	    int m = static_cast<int>(floor(s / 60.0));
 
 	    if (m >= 1) {
 		strZoom = strZoom.sprintf("%02d:%02d min", m, s % 60);
 	    } else if (s >= 1) {
 		strZoom = strZoom.sprintf("%d sec", s);
 	    } else if (ms >= 1) {
-		strZoom = strZoom.sprintf("%d ms", (int)round(ms));
+		strZoom = strZoom.sprintf("%d ms",
+		    static_cast<int>(round(ms)));
 	    } else if (ms >= 0.01) {
 		strZoom = strZoom.sprintf("%0.3g ms", ms);
 	    }
 	} else {
 	    // percent mode
-	    double percent = (double)100.0 / zoom;
-	    strZoom = KwavePlugin::zoom2string(percent);
+	    double percent = 100.0 / zoom;
+	    strZoom = Kwave::Plugin::zoom2string(percent);
 	}
     }
 
@@ -996,20 +1043,21 @@ void TopWidget::setStatusInfo(unsigned int length, unsigned int /*tracks*/,
 
     // length in milliseconds
     if (length) {
-	ms = (rate) ? (((double)length / (double)rate) * 1E3) : 0;
-	txt = " " + i18n("Length: %1", KwavePlugin::ms2string(ms)) +
-	    " " + i18n("(%1 samples)", KwavePlugin::dottedNumber(length)) +
+	ms = (rate) ? (static_cast<double>(length) /
+	    static_cast<double>(rate) * 1E3) : 0;
+	txt = " " + i18n("Length: %1", Kwave::Plugin::ms2string(ms)) +
+	    " " + i18n("(%1 samples)", Kwave::Plugin::dottedNumber(length)) +
 	    " ";
     } else txt = "";
-    statusBar()->changeItem(txt, STATUS_ID_SIZE);
+    m_lbl_status_size->setText(txt);
 
     // sample rate and resolution
     if (bits) {
 	QString khz = "%0.3f";
-	khz = khz.sprintf("%0.3f", (double)rate * 1E-3);
+	khz = khz.sprintf("%0.3f", static_cast<double>(rate) * 1E-3);
 	txt = " "+i18n("Mode: %1 kHz@%2 bit", khz, bits)+" ";
     } else txt = "";
-    statusBar()->changeItem(txt, STATUS_ID_MODE);
+    m_lbl_status_mode->setText(txt);
 
 }
 
@@ -1030,6 +1078,11 @@ void TopWidget::setTrackInfo(unsigned int tracks)
     // enable/disable all items that depend on having a signal
     bool have_signal = (tracks != 0);
     m_menu_manager->setItemEnabled("@SIGNAL", have_signal);
+
+    // revert is not possible if no signal at all is present
+    if (!have_signal)
+	m_menu_manager->setItemEnabled("ID_FILE_REVERT", false);
+
 }
 
 //***************************************************************************
@@ -1047,27 +1100,65 @@ void TopWidget::setSelectedTimeInfo(unsigned int offset, unsigned int length,
 
 	unsigned int last = offset + ((length) ? length-1 : 0);
 	if (rate == 0) sample_mode = true; // force sample mode if rate==0
-	QString txt = " "+i18n("Selected")+": %1...%2 (%3) ";
+	QString txt = " "+i18n("Selected")+": %1...%2 (%3)";
 	if (sample_mode) {
-	    txt = txt.arg(offset).arg(last).arg(
-	          KwavePlugin::dottedNumber(length) + " " +
+	    txt = txt.arg(
+	          Kwave::Plugin::dottedNumber(offset)).arg(
+	          Kwave::Plugin::dottedNumber(last)).arg(
+	          Kwave::Plugin::dottedNumber(length) + " " +
 	          i18n("samples"));
 	} else {
-	    double ms_first = (double)offset * 1E3 / rate;
-	    double ms_last  = (double)(last+1)   * 1E3 / rate;
+	    double ms_first = static_cast<double>(offset)   * 1E3 / rate;
+	    double ms_last  = static_cast<double>(last + 1) * 1E3 / rate;
 	    double ms = (ms_last - ms_first);
-	    txt = txt.arg(KwavePlugin::ms2string(ms_first)).arg(
-		KwavePlugin::ms2string(ms_last)).arg(
-		KwavePlugin::ms2string(ms));
+	    txt = txt.arg(Kwave::Plugin::ms2string(ms_first)).arg(
+		Kwave::Plugin::ms2string(ms_last)).arg(
+		Kwave::Plugin::ms2string(ms));
 	}
 
+	m_lbl_status_cursor->setText("");
 	statusBar()->showMessage(txt, 4000);
 	m_menu_manager->setItemEnabled("@SELECTION", true);
     } else {
+	// show cursor position
+	// Position: 02:00
+	bool sample_mode = false;
+
+	if (rate == 0) sample_mode = true; // force sample mode if rate==0
+	if (sample_mode) {
+	    m_lbl_status_cursor->setText("");
+	} else {
+	    QString txt = i18n("Position")+": %1";
+	    double ms_first = static_cast<double>(offset) * 1E3 / rate;
+	    txt = txt.arg(Kwave::Plugin::ms2string(ms_first));
+	    m_lbl_status_cursor->setText(txt);
+	}
+
 	m_menu_manager->setItemEnabled("@SELECTION", false);
     }
 }
 
+//***************************************************************************
+void TopWidget::updatePlaybackPos(unsigned int offset)
+{
+    if (!m_plugin_manager) return;
+    if (!m_main_widget) return;
+
+    bool playing = m_main_widget->playbackController().running();
+    if (!playing) return;
+
+    QString txt = i18n("Playback")+": %1";
+    double rate = m_plugin_manager->signalRate();
+    if (rate > 0) {
+	double ms = static_cast<double>(offset) * 1E3 / rate;
+	txt = txt.arg(Kwave::Plugin::ms2string(ms));
+    } else {
+	txt = txt.arg(Kwave::Plugin::dottedNumber(offset) + " " +
+	    i18n("samples"));
+    }
+    statusBar()->showMessage(txt, 2000);
+}
+
 //***************************************************************************
 void TopWidget::setUndoRedoInfo(const QString &undo, const QString &redo)
 {
@@ -1125,6 +1216,13 @@ void TopWidget::mouseChanged(int mode)
     }
 }
 
+//***************************************************************************
+void TopWidget::clipboardChanged(bool data_available)
+{
+    if (!m_menu_manager) return;
+    m_menu_manager->setItemEnabled("@CLIPBOARD", data_available);
+}
+
 //***************************************************************************
 void TopWidget::updateRecentFiles()
 {
@@ -1153,6 +1251,11 @@ void TopWidget::updateMenu()
     // enable/disable all items that depend on having a label
     bool have_labels = (!signalManager().fileInfo().labels().isEmpty());
     m_menu_manager->setItemEnabled("@LABELS", have_labels);
+
+    // enable/disable all items that depend on having something in the
+    // clipboard
+    bool have_clipboard_data = !ClipBoard::instance().isEmpty();
+    clipboardChanged(have_clipboard_data);
 }
 
 //***************************************************************************
