@@ -30,6 +30,7 @@
 #include <kurl.h>
 
 class QCloseEvent;
+class QLabel;
 class QTextStream;
 class QTimer;
 
@@ -83,7 +84,7 @@ public:
     /**
      * Returns the reference to the Kwave application
      */
-    inline KwaveApp &getKwaveApp() { return m_app; };
+    inline KwaveApp &getKwaveApp() { return m_app; }
 
     /**
      * Parses a text stream line by line and executes each line
@@ -155,6 +156,12 @@ private slots:
     void setSelectedTimeInfo(unsigned int offset, unsigned int length,
                              double rate);
 
+    /**
+     * updates the playback position in the status bar
+     * @param offset the current playback position [samples]
+     */
+    void updatePlaybackPos(unsigned int offset);
+
     /**
      * Sets the descriptions of the last undo and redo action. If the
      * name is zero or zero-length, the undo / redo is currently not
@@ -168,6 +175,9 @@ private slots:
      */
     void mouseChanged(int mode);
 
+    /** updates the menus when the clipboard has become empty/full */
+    void clipboardChanged(bool data_available);
+
     /** Updates the menu by enabling/disabling some entries */
     void updateMenu();
 
@@ -187,34 +197,34 @@ private slots:
     void blinkPause();
 
     /** toolbar: "file/new" */
-    void toolbarFileNew()    { executeCommand("plugin(newsignal)"); };
+    void toolbarFileNew()    { executeCommand("plugin(newsignal)"); }
 
     /** toolbar: "file/open" */
-    void toolbarFileOpen()   { executeCommand("open () "); };
+    void toolbarFileOpen()   { executeCommand("open () "); }
 
     /** toolbar: "file/save" */
-    void toolbarFileSave()   { executeCommand("save () "); };
+    void toolbarFileSave()   { executeCommand("save () "); }
 
     /** toolbar: "edit/undo" */
-    void toolbarEditUndo()   { executeCommand("undo () "); };
+    void toolbarEditUndo()   { executeCommand("undo () "); }
 
     /** toolbar: "edit/redo" */
-    void toolbarEditRedo()   { executeCommand("redo () "); };
+    void toolbarEditRedo()   { executeCommand("redo () "); }
 
     /** toolbar: "edit/cut" */
-    void toolbarEditCut()    { executeCommand("cut () "); };
+    void toolbarEditCut()    { executeCommand("cut () "); }
 
     /** toolbar: "edit/copy" */
-    void toolbarEditCopy()   { executeCommand("copy () "); };
+    void toolbarEditCopy()   { executeCommand("copy () "); }
 
     /** toolbar: "edit/paste" */
-    void toolbarEditPaste()  { executeCommand("paste () "); };
+    void toolbarEditPaste()  { executeCommand("paste () "); }
 
     /** toolbar: "edit/erase" */
-    void toolbarEditErase()  { executeCommand("plugin(zero)"); };
+    void toolbarEditErase()  { executeCommand("plugin(zero)"); }
 
     /** toolbar: "edit/delete" */
-    void toolbarEditDelete() { executeCommand("delete () "); };
+    void toolbarEditDelete() { executeCommand("delete () "); }
 
     /** called if the signal now or no longer is modified */
     void modifiedChanged(bool);
@@ -380,6 +390,15 @@ private:
     /** member id of the "zoom factor" combobox in the toolbar */
     QAction *m_action_zoomselect;
 
+    /** status bar label for length of the signal */
+    QLabel *m_lbl_status_size;
+
+    /** status bar label for mode information */
+    QLabel *m_lbl_status_mode;
+
+    /** status bar label for cursor / playback position */
+    QLabel *m_lbl_status_cursor;
+
 };
 
 #endif /* _TOP_WIDGET_H_ */
