@@ -19,6 +19,7 @@
 #include "math.h"
 
 #include <QMutableListIterator>
+#include <QColor>
 #include <QPainter>
 
 #include "libkwave/MultiTrackReader.h"
@@ -36,8 +37,8 @@ OverViewCache::OverViewCache(SignalManager &signal, unsigned int src_offset,
                              unsigned int src_length,
                              const QList<unsigned int> *src_tracks)
     :m_signal(signal), m_min(), m_max(), m_state(), m_count(0), m_scale(1),
-     m_lock(), m_src_offset(src_offset), m_src_length(src_length),
-     m_src_tracks(), m_src_deleted()
+     m_lock(QMutex::Recursive), m_src_offset(src_offset),
+     m_src_length(src_length), m_src_tracks(), m_src_deleted()
 {
     // connect to the signal manager
     SignalManager *sig = &signal;
@@ -77,6 +78,8 @@ OverViewCache::OverViewCache(SignalManager &signal, unsigned int src_offset,
 //***************************************************************************
 OverViewCache::~OverViewCache()
 {
+    QMutexLocker lock(&m_lock);
+
     m_state.clear();
     m_min.clear();
     m_max.clear();
@@ -91,6 +94,8 @@ unsigned int OverViewCache::sourceLength()
 //***************************************************************************
 void OverViewCache::scaleUp()
 {
+    QMutexLocker lock(&m_lock);
+
     Q_ASSERT(m_scale);
     if (!m_scale) return;
 
@@ -155,6 +160,8 @@ void OverViewCache::scaleUp()
 //***************************************************************************
 void OverViewCache::scaleDown()
 {
+    QMutexLocker lock(&m_lock);
+
     const unsigned int len = sourceLength();
     unsigned int new_scale = static_cast<unsigned int>(
 	rint(ceil(len/CACHE_SIZE)));
@@ -170,6 +177,8 @@ void OverViewCache::scaleDown()
 //***************************************************************************
 int OverViewCache::trackIndex(unsigned int track_nr)
 {
+    QMutexLocker lock(&m_lock);
+
     if (!m_src_tracks.isEmpty() || !m_src_deleted.isEmpty()) {
 	return m_src_tracks.indexOf(track_nr);
     } else {
@@ -181,6 +190,8 @@ int OverViewCache::trackIndex(unsigned int track_nr)
 void OverViewCache::invalidateCache(unsigned int track, unsigned int first,
                                     unsigned int last)
 {
+    QMutexLocker lock(&m_lock);
+
 //     qDebug("OverViewCache::invalidateCache(%u, %u, %u)",track,first,last);
     if (m_state.isEmpty()) return;
     int cache_track = trackIndex(track);
@@ -406,20 +417,31 @@ void OverViewCache::slotSamplesModified(unsigned int track,
         last = m_src_offset+sourceLength()-1;
     first -= m_src_offset;
     last  -= m_src_offset;
-    first = (unsigned int)floor(first / m_scale);
-    last  = (unsigned int)ceil(last / m_scale);
+    first = static_cast<unsigned int>(floor(first / m_scale));
+    last  = static_cast<unsigned int>(ceil(last / m_scale));
     invalidateCache(track, first, last);
     emit changed();
 }
 
 //***************************************************************************
-QBitmap OverViewCache::getOverView(int width, int height)
+QImage OverViewCache::getOverView(int width, int height,
+                                  const QColor &fg, const QColor &bg)
 {
-    QBitmap bitmap(width, height);
-    bitmap.fill(Qt::color0);
+    QMutexLocker lock(&m_lock);
+
+    QImage bitmap(width, height, QImage::Format_ARGB32_Premultiplied);
+    if (!width || !height || bitmap.isNull()) return bitmap;
+
+    QPainter p;
+    p.begin(&bitmap);
+    p.fillRect(bitmap.rect(), bg);
+    p.setPen(fg);
 
     const unsigned int length = sourceLength();
-    if (!length) return bitmap; // stay empty if no data available
+    if (!length) {
+	p.end();
+	return bitmap; // stay empty if no data available
+    }
 
     QList<unsigned int> track_list;
     if (!m_src_tracks.isEmpty() || !m_src_deleted.isEmpty()) {
@@ -428,13 +450,21 @@ QBitmap OverViewCache::getOverView(int width, int height)
     } else {
 	track_list = m_signal.allTracks();
     }
+
     MultiTrackReader src(m_signal, track_list, m_src_offset,
 	m_src_offset+length-1);
-    Kwave::SampleArray buf;
+    Q_ASSERT(m_min.count() == m_max.count());
+    Q_ASSERT(m_min.count() == m_state.count());
+
+    // abort if the track count has recently changed
+    if (m_state.count() != static_cast<int>(src.tracks())) {
+	qWarning("OverViewCache::getOverView(): track count has changed");
+	p.end();
+	return bitmap;
+    }
 
     // loop over all min/max buffers and make their content valid
-    Q_ASSERT(m_state.count() == static_cast<int>(src.tracks()));
-    for (int t=0; (t < m_state.count()) && !src.isEmpty(); ++t) {
+    for (int t = 0; (t < m_state.count()) && !src.isEmpty(); ++t) {
 	unsigned int count = length / m_scale;
 	if (count > CACHE_SIZE) count = 0;
 
@@ -442,41 +472,33 @@ QBitmap OverViewCache::getOverView(int width, int height)
 	signed char *max = m_max[t].data();
 	CacheState *state = m_state[t].data();
 	SampleReader *reader = src[t];
+	Q_ASSERT(reader);
+	if (!reader) continue;
 
 	for (unsigned int ofs=0; ofs < count; ++ofs) {
 	    if (state[ofs] == Valid)  continue;
 	    if (state[ofs] == Unused) continue;
 
+	    // get min/max
 	    sample_t min_sample = SAMPLE_MAX;
 	    sample_t max_sample = SAMPLE_MIN;
-	    unsigned int first = ofs*m_scale;
-	    buf.resize(m_scale);
-	    unsigned int count = buf.size();
-	    Q_ASSERT(count >= m_scale);
-	    if (count < m_scale) break; // out of memory
-
-	    reader->seek(m_src_offset+first);
-	    count = reader->read(buf, 0, m_scale);
-	    while (count--) {
-		sample_t sample = buf[count];
-		if (sample > max_sample) max_sample = sample;
-		if (sample < min_sample) min_sample = sample;
-	    }
+	    const unsigned int first = m_src_offset + (ofs * m_scale);
+	    const unsigned int last  = first + m_scale - 1;
+	    reader->minMax(first, last, min_sample, max_sample);
 
 	    min[ofs] = min_sample >> (SAMPLE_BITS - 8);
 	    max[ofs] = max_sample >> (SAMPLE_BITS - 8);
 	    state[ofs] = Valid;
 	}
     }
-    if ((width < 2) || (height < 2) || (length/m_scale < 2))
-	return bitmap; // empty ?
 
-    QPainter p;
-    p.begin(&bitmap);
-    p.setPen(Qt::color1);
+    if ((width < 2) || (height < 2) || (length/m_scale < 2)) {
+	p.end();
+	return bitmap; // empty ?
+    }
 
     // loop over all min/max buffers
-    for (int x=0; (x < width) && (m_state.count()) && !src.isEmpty(); ++x) {
+    for (int x = 0; (x < width) && (m_state.count()) && !src.isEmpty(); ++x) {
 	unsigned int count = length / m_scale;
 	if (count > CACHE_SIZE) count = 1;
 
@@ -493,7 +515,11 @@ QBitmap OverViewCache::getOverView(int width, int height)
 	int maximum = -127;
 	for (; index <= last_index; ++index) {
 	    // loop over all tracks
-	    for (int t=0; t < m_state.count(); ++t) {
+	    Q_ASSERT(m_min.count() == m_state.count());
+	    Q_ASSERT(m_max.count() == m_state.count());
+	    for (int t = 0; t < m_state.count(); ++t) {
+		Q_ASSERT(t < m_min.count());
+		Q_ASSERT(t < m_max.count());
 		signed char *min = m_min[t].data();
 		signed char *max = m_max[t].data();
 		CacheState *state = m_state[t].data();
