@@ -40,7 +40,7 @@ SelectTimeWidget::SelectTimeWidget(QWidget *widget)
 }
 
 //***************************************************************************
-void SelectTimeWidget::init(Mode mode, double range, double sample_rate,
+void SelectTimeWidget::init(Mode mode, unsigned int range, qreal sample_rate,
                             unsigned int offset, unsigned int signal_length)
 {
     m_mode  = mode;
@@ -63,7 +63,7 @@ void SelectTimeWidget::init(Mode mode, double range, double sample_rate,
     edSamples->setRange(0, m_length-m_offset, 1);
 
     // set range of time controls
-    int t = (int)rint((m_length * 1E3) / m_rate);
+    int t = static_cast<int>(rint((m_length * 1E3) / m_rate));
     sbMilliseconds->setMaximum(t);
     t /= 1000;
     sbSeconds->setMaximum(t);
@@ -73,13 +73,13 @@ void SelectTimeWidget::init(Mode mode, double range, double sample_rate,
     sbHours->setMaximum(t);
 
     // activate the current mode
-    setMode(m_mode);
+    setMode(mode);
     m_range = range;
 
     // set initial values
     switch (m_mode) {
 	case byTime: {
-	    unsigned int t = (unsigned int)ceil(m_range);
+	    unsigned int t = m_range;
 	    sbMilliseconds->setValue(t % 1000);
 	    t /= 1000;
 	    sbSeconds->setValue(t % 60);
@@ -90,24 +90,24 @@ void SelectTimeWidget::init(Mode mode, double range, double sample_rate,
 	    break;
 	}
 	case bySamples: {
-            unsigned int samples = (unsigned int)rint(m_range);
+            unsigned int samples = m_range;
 	    Q_ASSERT(samples <= INT_MAX);
 	    if (samples > INT_MAX) samples = INT_MAX;
-	    edSamples->setValue((int)samples);
+	    edSamples->setValue(static_cast<int>(samples));
 	    break;
 	}
 	case byPercents: {
-	    sbPercents->setValue((int)rint(m_range));
+	    sbPercents->setValue(static_cast<int>(m_range));
 	    break;
 	}
     }
 
     // connect mode controls
-    QObject::connect(rbTime, SIGNAL(clicked(bool)),
+    QObject::connect(rbTime, SIGNAL(toggled(bool)),
                      this, SLOT(modeChanged(bool)));
-    QObject::connect(rbSamples,SIGNAL(clicked(bool)),
+    QObject::connect(rbSamples,SIGNAL(toggled(bool)),
                      this, SLOT(modeChanged(bool)));
-    QObject::connect(rbPercents,SIGNAL(clicked(bool)),
+    QObject::connect(rbPercents,SIGNAL(toggled(bool)),
                      this, SLOT(modeChanged(bool)));
 
     connect();
@@ -125,7 +125,7 @@ void SelectTimeWidget::init(Mode mode, double range, double sample_rate,
 	    samplesChanged(0);
 	    break;
 	case byPercents:
-	    percentsChanged((int)m_range);
+	    percentsChanged(static_cast<int>(m_range));
 	    break;
     }
 
@@ -188,21 +188,25 @@ void SelectTimeWidget::disconnect()
 //***************************************************************************
 void SelectTimeWidget::setMode(Mode new_mode)
 {
-    // first disable all modes
-    rbTime->setChecked(false);
-    rbSamples->setChecked(false);
-    rbPercents->setChecked(false);
-
-    // then enable the selected one
+    // enable the selected mode
     switch (new_mode) {
 	case byTime:
 	    rbTime->setChecked(true);
+	    Q_ASSERT(rbTime->isChecked());
+	    Q_ASSERT(!rbSamples->isChecked());
+	    Q_ASSERT(!rbPercents->isChecked());
 	    break;
 	case bySamples:
 	    rbSamples->setChecked(true);
+	    Q_ASSERT(!rbTime->isChecked());
+	    Q_ASSERT(rbSamples->isChecked());
+	    Q_ASSERT(!rbPercents->isChecked());
 	    break;
 	case byPercents:
 	    rbPercents->setChecked(true);
+	    Q_ASSERT(!rbTime->isChecked());
+	    Q_ASSERT(!rbSamples->isChecked());
+	    Q_ASSERT(rbPercents->isChecked());
 	    break;
     }
     m_mode = new_mode;
@@ -213,14 +217,14 @@ void SelectTimeWidget::modeChanged(bool checked)
 {
     if (!checked) return; // ignore disabling of radio buttons
 
-    if (rbTime->isChecked() && (m_mode != byTime)) {
+    if (rbTime->isChecked()) {
 	m_mode = byTime;
 	rbSamples->setChecked(false);
 	rbPercents->setChecked(false);
 	timeChanged(0); // (sets m_range)
     }
 
-    if (rbSamples->isChecked() && (m_mode != bySamples)) {
+    if (rbSamples->isChecked()) {
 	m_mode = bySamples;
 	rbTime->setChecked(false);
 	rbPercents->setChecked(false);
@@ -236,7 +240,7 @@ void SelectTimeWidget::modeChanged(bool checked)
 
     }
 
-    if (rbPercents->isChecked() && (m_mode != byPercents)) {
+    if (rbPercents->isChecked()) {
 	m_mode = byPercents;
 	rbTime->setChecked(false);
 	rbSamples->setChecked(false);
@@ -278,13 +282,14 @@ void SelectTimeWidget::timeChanged(int)
     Q_ASSERT((hours>=0) && (minutes>=0) && (seconds>=0) && (milliseconds>=0));
 
     int ms =
-        (int)milliseconds +
-        ((int)seconds + ((int)minutes +
-        ((int)hours * 60L)) * 60L) * 1000L;
+        milliseconds +
+        (seconds + (minutes +
+        (hours * 60)) * 60) * 1000;
     if (ms < 0) ms = 0;
 
     // limit time
-    long int max_ms = (long int)ceil(((m_length - m_offset)*1E3) / m_rate);
+    long int max_ms = static_cast<long int>(
+	ceil(((m_length - m_offset) * 1E3) / m_rate));
     if (ms > max_ms) ms = max_ms;
     long int t = ms;
 
@@ -301,11 +306,10 @@ void SelectTimeWidget::timeChanged(int)
     sbHours->setValue(hours);
 
     // update the other widgets
-    unsigned int samples = (unsigned int)ceil((double)ms * m_rate * 1E-3);
-    Q_ASSERT(samples <= INT_MAX);
-    if (samples > INT_MAX) samples = INT_MAX;
-    edSamples->setValue((int)samples);
-    sbPercents->setValue((int)(100.0 * (double)ms / (m_length/m_rate*1E3)));
+    int samples = timeToSamples(byTime, ms, m_rate, m_length);
+    edSamples->setValue(samples);
+    int percents = samplesToTime(byPercents, samples, m_rate, m_length);
+    sbPercents->setValue(percents);
 
     // set range in byTime mode [ms]
     m_range = ms;
@@ -337,7 +341,7 @@ void SelectTimeWidget::samplesChanged(int)
     if (samples > max_samples) samples = max_samples;
 
     // update the other widgets
-    unsigned int t = (unsigned int)rint((double)samples * 1E3 / m_rate);
+    unsigned int t = samplesToTime(byTime, samples, m_rate, m_length);
     sbMilliseconds->setValue(t % 1000);
     t /= 1000;
     sbSeconds->setValue(t % 60);
@@ -346,8 +350,8 @@ void SelectTimeWidget::samplesChanged(int)
     t /= 60;
     sbHours->setValue(t);
 
-    double percents = (100.0 * (double)samples) / (double)(m_length);
-    sbPercents->setValue((int)rint(percents));
+    int percents = samplesToTime(byPercents, samples, m_rate, m_length);
+    sbPercents->setValue(percents);
 
     // update in samples mode
     m_range = samples;
@@ -367,30 +371,26 @@ void SelectTimeWidget::percentsChanged(int p)
     if (m_mode != byPercents) return;
     disconnect();
 
-    // get value
-    double percents = p;
-
     // limit to rest of signal
-    double max_percents = 100.0 * (double)(m_length-m_offset)/(double)m_length;
-    if (percents > max_percents) {
-	percents = max_percents;
-	p = (int)percents;
+    int max_percents = 100;
+    if (m_length)
+	max_percents = (100 * static_cast<quint64>(m_length - m_offset)) /
+	static_cast<quint64>(m_length);
+    if (p > max_percents) {
+	p = max_percents;
     }
 
     // update in byPercents mode [0...100]
-    m_range = percents;
-    p = (int)percents;
+    m_range = p;
 
     if (slidePercents->value() != p) slidePercents->setValue(p);
     if (sbPercents->value() != p) sbPercents->setValue(p);
 
     // update the other widgets
-    unsigned int samples = (unsigned int)((double)m_length*percents/100.0);
-    Q_ASSERT(samples <= INT_MAX);
-    if (samples > INT_MAX) samples = INT_MAX;
+    int samples = timeToSamples(byPercents, p, m_rate, m_length);
     edSamples->setValue(samples);
 
-    unsigned int t = (unsigned int)ceil(((double)samples * 1E3) / m_rate);
+    unsigned int t = samplesToTime(byTime, samples, m_rate, m_length);
     sbMilliseconds->setValue(t % 1000);
     t /= 1000;
     sbSeconds->setValue(t % 60);
@@ -399,7 +399,7 @@ void SelectTimeWidget::percentsChanged(int p)
     t /= 60;
     sbHours->setValue(t);
 
-    emit valueChanged((unsigned int)samples); // emit the change
+    emit valueChanged(samples); // emit the change
     connect();
 }
 
@@ -429,7 +429,8 @@ void SelectTimeWidget::setOffset(unsigned int offset)
     // update all widgets
     disconnect();
 
-    int t = (int)ceil(((double)samples * 1E3) / m_rate);
+    int t = static_cast<int>(ceil((static_cast<double>(samples) * 1E3) /
+	m_rate));
     sbMilliseconds->setValue(t);
     t /= 1000;
     sbSeconds->setValue(t);
@@ -442,12 +443,72 @@ void SelectTimeWidget::setOffset(unsigned int offset)
     if (samples > INT_MAX) samples = INT_MAX;
     edSamples->setValue(samples);
 
-    double percents = 100.0*(double)samples/(double)(m_length);
-    sbPercents->setValue((int)percents);
+    double percents = 100.0 * static_cast<double>(samples) /
+	static_cast<double>(m_length);
+    sbPercents->setValue(static_cast<int>(percents));
 
     connect();
 }
 
+//***************************************************************************
+unsigned int SelectTimeWidget::samples() const
+{
+    return (edSamples) ? edSamples->value() : 0;
+}
+
+//***************************************************************************
+unsigned int SelectTimeWidget::timeToSamples(
+    Mode mode, unsigned int time, qreal rate, unsigned int length)
+{
+    unsigned int pos = 0;
+    switch (mode) {
+	case SelectTimeWidget::byTime:
+	    // convert from ms to samples
+	    pos = static_cast<unsigned int>(ceil(
+		static_cast<double>(time) * rate * 1E-3));
+	    break;
+	case SelectTimeWidget::bySamples:
+	    // simple case -> already in samples
+	    pos = time;
+	    break;
+	case SelectTimeWidget::byPercents:
+	    // by percentage of whole signal
+	    pos = static_cast<unsigned int>(rint(
+		static_cast<double>(length * (time / 100.0))));
+	    break;
+    }
+
+    if (pos > INT_MAX) pos = INT_MAX;
+    return pos;
+}
+
+//***************************************************************************
+unsigned int SelectTimeWidget::samplesToTime(
+    Mode mode, unsigned int samples, qreal rate, unsigned int length)
+{
+    unsigned int time = 0;
+
+    switch (mode) {
+	case SelectTimeWidget::byTime:
+	    // convert from samples to ms
+	    time = static_cast<unsigned int>(
+		rint(static_cast<double>(samples) * 1E3 / rate));
+	    break;
+	case SelectTimeWidget::bySamples:
+	    // simple case -> already in samples
+	    time = samples;
+	    break;
+	case SelectTimeWidget::byPercents:
+	    // by percentage of whole signal
+	    time = static_cast<unsigned int>(100.0 *
+		static_cast<double>(samples) /
+		static_cast<double>(length));
+	    break;
+    }
+
+    return time;
+}
+
 //***************************************************************************
 #include "SelectTimeWidget.moc"
 //***************************************************************************
