@@ -33,6 +33,7 @@
 #include <QMouseEvent>
 #include <QPaintEvent>
 #include <QResizeEvent>
+#include <QTime>
 #include <QToolTip>
 
 #include <kcursor.h>
@@ -42,6 +43,7 @@
 #include <kfiledialog.h>
 #include <kiconloader.h>
 
+#include "libkwave/ClipBoard.h"
 #include "libkwave/CodecManager.h"
 #include "libkwave/FileInfo.h"
 #include "libkwave/KwaveDrag.h"
@@ -53,7 +55,6 @@
 #include "libkwave/Parser.h"
 #include "libkwave/SampleReader.h"
 #include "libkwave/SampleWriter.h"
-#include "libkwave/Signal.h"
 #include "libkwave/SignalManager.h"
 #include "libkwave/Track.h"
 #include "libkwave/undo/UndoTransactionGuard.h"
@@ -277,8 +278,7 @@ bool SignalWidget::executeNavigationCommand(const QString &command)
 {
     if (!command.length()) return true;
     Parser parser(command);
-
-    unsigned int visible_samples = pixels2samples(m_width);
+    const unsigned int visible_samples = pixels2samples(m_width);
 
     if (false) {
     // zoom
@@ -292,6 +292,12 @@ bool SignalWidget::executeNavigationCommand(const QString &command)
 	zoomAll();
     CASE_COMMAND("zoomnormal")
 	zoomNormal();
+    // navigation
+    CASE_COMMAND("goto")
+	unsigned int offset = parser.toUInt();
+	setOffset((offset > (visible_samples / 2)) ?
+	          (offset - (visible_samples / 2)) : 0);
+	selectRange(offset, 0);
     CASE_COMMAND("scrollright")
 	setOffset(m_offset + visible_samples / 10);
     CASE_COMMAND("scrollleft")
@@ -333,6 +339,57 @@ bool SignalWidget::executeNavigationCommand(const QString &command)
 	selectRange(m_offset, pixels2samples(m_width) - 1);
     CASE_COMMAND("selectnone")
 	selectRange(m_offset, 0);
+    } else return false;
+
+    return true;
+}
+
+//***************************************************************************
+bool SignalWidget::executeCommand(const QString &command)
+{
+    InhibitRepaintGuard inhibit(*this);
+    Parser parser(command);
+
+    const unsigned int offset = m_signal_manager.selection().offset();
+    const unsigned int length = m_signal_manager.selection().length();
+
+    if (!command.length()) return true;
+
+    if (executeNavigationCommand(command)) {
+	return true;
+    // copy & paste + clipboard
+    CASE_COMMAND("copy")
+	qDebug("copy(%u,%u)", offset, length);
+	if (length) {
+	    ClipBoard &clip = ClipBoard::instance();
+	    clip.copy(
+		this,
+		m_signal_manager,
+		m_signal_manager.selectedTracks(),
+		offset, length
+	    );
+	}
+    CASE_COMMAND("paste")
+	ClipBoard &clip = ClipBoard::instance();
+	if (clip.isEmpty()) return false;
+	if (!m_signal_manager.selectedTracks().size()) return false;
+
+	UndoTransactionGuard undo(m_signal_manager, i18n("paste"));
+	clip.paste(this, m_signal_manager, offset, length);
+    CASE_COMMAND("cut")
+	if (length) {
+	    ClipBoard &clip = ClipBoard::instance();
+	    clip.copy(
+		this,
+		m_signal_manager,
+		m_signal_manager.selectedTracks(),
+		offset, length
+	    );
+	    UndoTransactionGuard undo(m_signal_manager, i18n("cut"));
+	    m_signal_manager.deleteRange(offset, length);
+	}
+    CASE_COMMAND("clipboard_flush")
+	ClipBoard::instance().clear();
     // label commands
     CASE_COMMAND("label")
 	unsigned int pos = parser.toUInt();
@@ -354,37 +411,40 @@ bool SignalWidget::executeNavigationCommand(const QString &command)
 //    CASE_COMMAND("savelabel")
 //	saveLabel(command);
     CASE_COMMAND("expandtolabel")
+	UndoTransactionGuard undo(m_signal_manager,
+	    i18n("expand selection to label"));
 	unsigned int selection_left  = m_signal_manager.selection().first();
 	unsigned int selection_right = m_signal_manager.selection().last();
 	if (labels().isEmpty()) return false; // we need labels for this
-	Label *label_left  = 0;
-	Label *label_right = 0;
+	Label label_left  = Label();
+	Label label_right = Label();
 	// the last label <= selection start -> label_left
 	// the first label >= selection end  -> label_right
-	foreach (Label *label, labels()) {
-	    if (!label) continue;
-	    unsigned int lp = label->pos();
+	foreach (Label label, labels()) {
+	    unsigned int lp = label.pos();
 	    if (lp <= selection_left)
 		label_left = label;
-	    if ((lp >= selection_right) && (!label_right)) {
+	    if ((lp >= selection_right) && (label_right.isNull())) {
 		label_right = label;
 		break; // done
 	    }
 	}
 	// default left label = start of file
-	selection_left = (label_left) ?
-	    label_left->pos() : 0;
+	selection_left = (label_left.isNull()) ? 0 :
+	    label_left.pos();
 	// default right label = end of file
-	selection_right = (label_right) ?
-	    label_right->pos() : m_signal_manager.length() - 1;
+	selection_right = (label_right.isNull()) ?
+	    m_signal_manager.length() - 1 : label_right.pos();
 	unsigned int length = selection_right - selection_left + 1;
 	selectRange(selection_left, length);
 
     CASE_COMMAND("selectnextlabels")
+	UndoTransactionGuard undo(m_signal_manager,
+	    i18n("select next labels"));
 	unsigned int selection_left;
 	unsigned int selection_right = m_signal_manager.selection().last();
-	Label *label_left  = 0;
-	Label *label_right = 0;
+	Label label_left  = Label();
+	Label label_right = Label();
 	if (labels().isEmpty()) return false; // we need labels for this
 
 	// special case: nothing selected -> select up to the first label
@@ -395,49 +455,49 @@ bool SignalWidget::executeNavigationCommand(const QString &command)
 	    // find the first label starting after the current selection
 	    LabelListIterator it(labels());
 	    while (it.hasNext()) {
-		Label *label = it.next();
-		if (!label) continue;
-		if (label->pos() >= selection_right) {
+		Label label = it.next();
+		if (label.pos() >= selection_right) {
 		    // take it as selection start
 		    label_left  = label;
 		    // and it's next one as selection end (might be null)
-		    label_right = it.hasNext() ? it.next() : 0;
+		    label_right = it.hasNext() ? it.next() : Label();
 		    break;
 		}
 	    }
 	    // default selection start = last label
-	    if (!label_left) label_left = labels().last();
-	    if (!label_left) return false; // no labels at all !?
-	    selection_left = label_left->pos();
+	    if (label_left.isNull()) label_left = labels().last();
+	    if (label_left.isNull()) return false; // no labels at all !?
+	    selection_left = label_left.pos();
 	}
 	// default selection end = end of the file
-	selection_right = (label_right) ?
-	    label_right->pos() : m_signal_manager.length() - 1;
+	selection_right = (label_right.isNull()) ?
+	    m_signal_manager.length() - 1 : label_right.pos();
 	unsigned int length = selection_right - selection_left + 1;
 	selectRange(selection_left, length);
 
     CASE_COMMAND("selectprevlabels")
+	UndoTransactionGuard undo(m_signal_manager,
+	    i18n("select previous labels"));
 	unsigned int selection_left  = m_signal_manager.selection().first();
 	unsigned int selection_right = m_signal_manager.selection().last();
-	Label *label_left  = 0;
-	Label *label_right = 0;
+	Label label_left  = Label();
+	Label label_right = Label();
 	if (labels().isEmpty()) return false; // we need labels for this
 
 	// find the last label before the start of the selection
-	foreach (Label *label, labels()) {
-	    if (!label) continue;
-	    if (label->pos() > selection_left)
+	foreach (Label label, labels()) {
+	    if (label.pos() > selection_left)
 		break; // done
 	    label_left  = label_right;
 	    label_right = label;
 	}
 	// default selection start = start of file
-	selection_left = (label_left) ?
-	    label_left->pos() : 0;
+	selection_left = (label_left.isNull()) ? 0 :
+	    label_left.pos();
 	// default selection end = first label
-	if (!label_right) label_right = labels().first();
-	if (!label_right) return false; // no labels at all !?
-	selection_right = label_right->pos();
+	if (label_right.isNull()) label_right = labels().first();
+	if (label_right.isNull()) return false; // no labels at all !?
+	selection_right = label_right.pos();
 	unsigned int length = selection_right - selection_left + 1;
 	selectRange(selection_left, length);
 
@@ -445,20 +505,21 @@ bool SignalWidget::executeNavigationCommand(const QString &command)
 //	markPeriods(command);
 //    CASE_COMMAND("saveperiods")
 //	savePeriods();
-    } else return false;
 
-    return true;
-}
-
-//***************************************************************************
-bool SignalWidget::executeCommand(const QString &command)
-{
-    InhibitRepaintGuard inhibit(*this);
-
-    if (!command.length()) return true;
-
-    if (executeNavigationCommand(command)) {
-	return true;
+    // track selection
+    CASE_COMMAND("select_all_tracks")
+	UndoTransactionGuard undo(m_signal_manager,
+	    i18n("select all tracks"));
+	foreach (unsigned int track, m_signal_manager.allTracks())
+	    m_signal_manager.selectTrack(track, true);
+    CASE_COMMAND("invert_track_selection")
+	UndoTransactionGuard undo(m_signal_manager,
+	    i18n("invert track selection"));
+	foreach (unsigned int track, m_signal_manager.allTracks())
+	    m_signal_manager.selectTrack(
+		track,
+		!m_signal_manager.trackSelected(track)
+	    );
     } else {
 	return m_signal_manager.executeCommand(command);
     }
@@ -617,8 +678,8 @@ qreal SignalWidget::getFullZoom()
     if (!length) {
         // no length: streaming mode -> start with a default
         // zoom, use one minute (just guessed)
-        length = (unsigned int)ceil(DEFAULT_DISPLAY_TIME *
-                                    m_signal_manager.rate());
+        length = static_cast<unsigned int>(ceil(DEFAULT_DISPLAY_TIME *
+	    m_signal_manager.rate()));
     }
 
     // example: width = 100 [pixels] and length = 3 [samples]
@@ -626,7 +687,8 @@ qreal SignalWidget::getFullZoom()
     //          -> 49.5 [pixels / sample]
     //          -> zoom = 1 / 49.5 [samples / pixel]
     // => full zoom [samples/pixel] = (length-1) / (width-1)
-    return (qreal)(length-1) / (qreal)(QWidget::width()-1);
+    return static_cast<qreal>(length - 1) /
+	   static_cast<qreal>(QWidget::width() - 1);
 }
 
 //***************************************************************************
@@ -664,7 +726,7 @@ void SignalWidget::fixZoomAndOffset()
     length = m_signal_manager.length();
     if (!length) {
 	// in streaming mode we have to use a guessed length
-	length = (unsigned int)ceil(width() * getFullZoom());
+	length = static_cast<unsigned int>(ceil(width() * getFullZoom()));
     }
 
     if (!m_width) return;
@@ -674,7 +736,8 @@ void SignalWidget::fixZoomAndOffset()
 
     // ensure that the zoom is in a proper range
     max_zoom = getFullZoom();
-    min_zoom = (qreal)MINIMUM_SAMPLES_PER_SCREEN / (qreal)m_width;
+    min_zoom = static_cast<qreal>(MINIMUM_SAMPLES_PER_SCREEN) /
+	       static_cast<qreal>(m_width);
     if (m_zoom < min_zoom) m_zoom = min_zoom;
     if (m_zoom > max_zoom) m_zoom = max_zoom;
 
@@ -800,7 +863,7 @@ void SignalWidget::zoomSelection()
 
     if (len) {
 	m_offset = ofs;
-	setZoom(((qreal)len) / (qreal)(m_width - 1));
+	setZoom((static_cast<qreal>(len)) / static_cast<qreal>(m_width - 1));
     }
 }
 
@@ -991,7 +1054,7 @@ void SignalWidget::contextMenuEvent(QContextMenuEvent *e)
     SignalManager *manager = &signalManager();
     bool have_signal = !manager->isEmpty();
     if (!have_signal)return;
-    bool have_selection = (manager->selection().length() != 0);
+    bool have_selection = (manager->selection().length() > 1);
     bool have_labels = !labels().isEmpty();
 
     QMenu *context_menu = new QMenu(this);
@@ -1048,7 +1111,8 @@ void SignalWidget::contextMenuEvent(QContextMenuEvent *e)
     context_menu->addSeparator();
     if (action_cut)   action_cut->setEnabled(have_selection);
     if (action_copy)  action_copy->setEnabled(have_selection);
-    if (action_paste) action_paste->setEnabled(have_selection);
+    if (action_paste)
+	action_paste->setEnabled(!ClipBoard::instance().isEmpty());
 
     int mouse_x = mapFromGlobal(e->globalPos()).x();
     if (mouse_x < 0) mouse_x = 0;
@@ -1114,15 +1178,15 @@ void SignalWidget::contextMenuEvent(QContextMenuEvent *e)
     unsigned int pos = m_offset + pixels2samples(mouse_x);
     m_selection->set(pos, pos);
 
-    Label *label = 0;
-    if ((label = findLabelNearMouse(mouse_x))) {
+    Label label;
+    if (!((label = findLabelNearMouse(mouse_x)).isNull())) {
 	// delete label ?
 	// label properties ?
 	action_label_new->setEnabled(false);
 	action_label_properties->setEnabled(true);
 	action_label_delete->setEnabled(true);
 
-	pos = label->pos();
+	pos = label.pos();
 	m_selection->set(pos, pos);
     }
 
@@ -1156,7 +1220,8 @@ void SignalWidget::contextMenuLabelDelete()
     Q_ASSERT(m_selection);
     if (!m_selection) return;
 
-    Label *label = m_signal_manager.findLabel(m_selection->left());
+    Label label = m_signal_manager.findLabel(m_selection->left());
+    if (label.isNull()) return;
     int index = m_signal_manager.labelIndex(label);
     forwardCommand(QString("deletelabel(%1)").arg(index));
 }
@@ -1167,7 +1232,9 @@ void SignalWidget::contextMenuLabelProperties()
     Q_ASSERT(m_selection);
     if (!m_selection) return;
 
-    Label *label = m_signal_manager.findLabel(m_selection->left());
+    Label label = m_signal_manager.findLabel(m_selection->left());
+    if (label.isNull()) return;
+
     labelProperties(label);
 }
 
@@ -1402,7 +1469,7 @@ void SignalWidget::showPosition(const QString &text, unsigned int pos,
     m_position_widget.hide();
 
     unsigned int t, h, m, s, tms;
-    t = (unsigned int)rint(ms * 10.0);
+    t = static_cast<unsigned int>(rint(ms * 10.0));
     tms = t % 10000;
     t /= 10000;
     s = t % 60;
@@ -1503,13 +1570,13 @@ void SignalWidget::mouseMoveEvent(QMouseEvent *e)
 	default: {
 	    unsigned int first = m_signal_manager.selection().first();
 	    unsigned int last  = m_signal_manager.selection().last();
-	    Label *label = findLabelNearMouse(mouse_x);
+	    Label label = findLabelNearMouse(mouse_x);
 
 	    // find out what is nearer: label or selection border ?
-	    if (label && (first != last) && isSelectionBorder(mouse_x)) {
+	    if (!label.isNull() && (first != last) && isSelectionBorder(mouse_x)) {
 		const unsigned int pos = m_offset + pixels2samples(mouse_x);
-		const unsigned int d_label = (pos > label->pos()) ?
-		    (pos - label->pos()) : (label->pos() - pos);
+		const unsigned int d_label = (pos > label.pos()) ?
+		    (pos - label.pos()) : (label.pos() - pos);
 		const unsigned int d_left = (pos > first) ?
 		    (pos - first) : (first - pos);
 		const unsigned int d_right = (pos > last) ?
@@ -1518,19 +1585,18 @@ void SignalWidget::mouseMoveEvent(QMouseEvent *e)
 		     ((d_label ^ 2) > (d_right ^ 2)) )
 		{
 		    // selection borders are nearer
-		    label = 0;
+		    label = Label();
 		}
 	    }
 
 	    // yes, this code gives the nifty cursor change....
-	    if (label) {
+	    if (!label.isNull()) {
 		setMouseMode(MouseAtSelectionBorder);
 		QString text = i18n("label #%1",
 		    m_signal_manager.labelIndex(label));
-		if (label->name().length())
-		    text += i18n(" (%1)", label->name());
-		showPosition(text, label->pos(), samples2ms(label->pos()),
-		    pos);
+		if (label.name().length())
+		    text += i18n(" (%1)", label.name());
+		showPosition(text, label.pos(), samples2ms(label.pos()), pos);
 		break;
 	    } else if ((first != last) && isSelectionBorder(mouse_x)) {
 		setMouseMode(MouseAtSelectionBorder);
@@ -1601,13 +1667,12 @@ void SignalWidget::paintEvent(QPaintEvent *)
     InhibitRepaintGuard inhibit(*this, false); // avoid recursion
 
 //     qDebug("SignalWidget::paintEvent()");
-// #define DEBUG
-// #ifdef DEBUG
-//    static struct timeval t_start;
-//    static struct timeval t_end;
-//    qreal t_elapsed;
-//    gettimeofday(&t_start,0);
-// #endif
+// #define DEBUG_REPAINT_TIMES
+#ifdef DEBUG_REPAINT_TIMES
+    QTime time;
+    time.start();
+#endif /* DEBUG_REPAINT_TIMES */
+
     QPainter p;
 
     int n_tracks = m_signal_manager.isClosed() ? 0 : tracks();
@@ -1677,16 +1742,22 @@ void SignalWidget::paintEvent(QPaintEvent *)
 	p.begin(&m_layer[LAYER_MARKERS]);
 	p.fillRect(0, 0, m_width, m_height, Qt::black);
 
-	foreach (Label *label, labels()) {
-	    if (!label) continue;
-	    unsigned int pos = label->pos();
+	int last_marker = -1;
+	foreach (const Label label, labels()) {
+	    unsigned int pos = label.pos();
 	    if (pos < m_offset) continue; // outside left
 	    int x = samples2pixels(pos - m_offset);
 	    if (x >= m_width) continue; // outside right
 
+	    // position must differ from the last one, otherwise we
+	    // would wipe out the last one with XOR mode
+	    if (x == last_marker) continue;
+
 	    p.setPen(Qt::cyan);
 	    p.setCompositionMode(QPainter::CompositionMode_Exclusion);
 	    p.drawLine(x, 0, x, m_height);
+
+	    last_marker = x;
 	}
 
 	p.end();
@@ -1710,8 +1781,10 @@ void SignalWidget::paintEvent(QPaintEvent *)
 		left  = samples2pixels(left - m_offset);
 		right = samples2pixels(right - m_offset);
 
-		if (right >= (unsigned int)(m_width)) right=m_width-1;
-		if (left > right) left = right;
+		if (right >= static_cast<unsigned int>(m_width))
+		    right=m_width-1;
+		if (left > right)
+		    left = right;
 
 		p.setPen(Qt::yellow);
 		if (left == right) {
@@ -1769,19 +1842,16 @@ void SignalWidget::paintEvent(QPaintEvent *)
     p.drawImage(0, 0, m_image);
     p.end();
 
-// #ifdef DEBUG
-//    gettimeofday(&t_end,0);
-//    t_elapsed = ((qreal)t_end.tv_sec*1.0E6+(qreal)t_end.tv_usec -
-// 	((qreal)t_start.tv_sec*1.0E6+(qreal)t_start.tv_usec)) * 1E-3;
-//    qDebug("SignalWidget::paintEvent() -- done, t=%0.3fms --",
-// 	t_elapsed);
-// #endif
+#ifdef DEBUG_REPAINT_TIMES
+   qDebug("SignalWidget::paintEvent() -- done, t=%d ms --", time.elapsed());
+#endif /* DEBUG_REPAINT_TIMES */
 }
 
 //***************************************************************************
 unsigned int SignalWidget::ms2samples(qreal ms)
 {
-    return (unsigned int)rint(ms * m_signal_manager.rate() / 1E3);
+    return static_cast<unsigned int>(
+	rint(ms * m_signal_manager.rate() / 1E3));
 }
 
 //***************************************************************************
@@ -1789,21 +1859,22 @@ qreal SignalWidget::samples2ms(unsigned int samples)
 {
     qreal rate = m_signal_manager.rate();
     if (rate == 0.0) return 0.0;
-    return (qreal)samples * 1E3 / rate;
+    return static_cast<qreal>(samples) * 1E3 / rate;
 }
 
 //***************************************************************************
 unsigned int SignalWidget::pixels2samples(int pixels) const
 {
     if ((pixels < 0) || (m_zoom <= 0.0)) return 0;
-    return (unsigned int)rint((qreal)pixels * m_zoom);
+    return static_cast<unsigned int>(rint(
+	static_cast<qreal>(pixels) * m_zoom));
 }
 
 //***************************************************************************
 int SignalWidget::samples2pixels(int samples) const
 {
     if (m_zoom == 0.0) return 0;
-    return (int)rint((qreal)samples / m_zoom);
+    return static_cast<int>(rint(static_cast<qreal>(samples) / m_zoom));
 }
 
 //***************************************************************************
@@ -1813,16 +1884,15 @@ int SignalWidget::displaySamples()
 }
 
 //***************************************************************************
-Label *SignalWidget::findLabelNearMouse(int x) const
+Label SignalWidget::findLabelNearMouse(int x) const
 {
     const int tol = SELECTION_TOLERANCE;
     unsigned int pos = m_offset + pixels2samples(x);
-    Label *nearest = 0;
-    int dmin = pixels2samples(SELECTION_TOLERANCE) ^ 2;
+    Label nearest;
+    unsigned int dmin = pixels2samples(SELECTION_TOLERANCE) + 1;
 
-    foreach (Label *label, labels()) {
-	if (!label) continue;
-	unsigned int lp = label->pos();
+    foreach (Label label, labels()) {
+	unsigned int lp = label.pos();
 	if (lp < m_offset) continue; // outside left
 	int lx = samples2pixels(lp - m_offset);
 	if (lx >= m_width) continue; // outside right
@@ -1830,7 +1900,7 @@ Label *SignalWidget::findLabelNearMouse(int x) const
 	if ((lx + tol < x) || (lx > x + tol))
 	    continue; // out of tolerance
 
-	int dist = (pos - label->pos()) ^ 2;
+	unsigned int dist = (pos > lp) ? (pos - lp) : (lp - pos);
 	if (dist < dmin) {
 	    // found a new "nearest" label
 	    dmin = dist;
@@ -1844,14 +1914,28 @@ Label *SignalWidget::findLabelNearMouse(int x) const
 //***************************************************************************
 void SignalWidget::addLabel(unsigned int pos)
 {
-    if (m_signal_manager.addLabel(pos)) {
-	// edit the label's properties
-	Label *label = m_signal_manager.findLabel(pos);
-	labelProperties(label);
+    UndoTransactionGuard undo(m_signal_manager, i18n("add label"));
 
-	refreshLayer(LAYER_MARKERS);
-	hidePosition();
+    // add a new label, with undo
+    if (!m_signal_manager.addLabel(pos)) {
+	m_signal_manager.abortUndoTransaction();
+	return;
     }
+
+    // find the new label
+    Label label = m_signal_manager.findLabel(pos);
+    if (label.isNull()) return;
+
+    // edit the properties of the new label
+    if (!labelProperties(label)) {
+	// aborted or failed -> delete (without undo)
+	int index = m_signal_manager.labelIndex(label);
+	m_signal_manager.deleteLabel(index, false);
+	m_signal_manager.abortUndoTransaction();
+    }
+
+    refreshMarkersLayer();
+    hidePosition();
 }
 
 ////****************************************************************************
@@ -1904,44 +1988,115 @@ void SignalWidget::addLabel(unsigned int pos)
 //}
 
 //***************************************************************************
-bool SignalWidget::labelProperties(Label *label)
+bool SignalWidget::labelProperties(Label &label)
 {
-    if (!label) return false;
+    if (label.isNull()) return false;
+    int index = m_signal_manager.labelIndex(label);
+    Q_ASSERT(index >= 0);
+    if (index < 0) return false;
 
-    LabelPropertiesWidget *dlg = new LabelPropertiesWidget(this);
-    Q_ASSERT(dlg);
-    if (!dlg) return false;
+    // try to modify the label. just in case that the user moves it
+    // to a position where we already have one, catch this situation
+    // and ask if he wants to abort, re-enter the label properties
+    // dialog or just replace (remove) the label at the target position
+    bool accepted;
+    unsigned int new_pos  = label.pos();
+    QString      new_name = label.name();
+    int old_index = -1;
+    while (true) {
+	// create and prepare the dialog
+	LabelPropertiesWidget *dlg = new LabelPropertiesWidget(this);
+	Q_ASSERT(dlg);
+	if (!dlg) return false;
+	dlg->setLabelIndex(index);
+	dlg->setLabelPosition(new_pos, m_signal_manager.length(),
+	    m_signal_manager.rate());
+	dlg->setLabelName(new_name);
 
-    dlg->setLabelIndex(m_signal_manager.labelIndex(label));
-    dlg->setLabelPosition(label->pos(), m_signal_manager.length(),
-	m_signal_manager.rate());
-    dlg->setLabelName(label->name());
-
-    bool accepted = (dlg->exec() == QDialog::Accepted);
-    if (accepted) {
-	UndoTransactionGuard undo(m_signal_manager, i18n("modify label"));
-	UndoModifyLabelAction *undo_modify =
-	    new UndoModifyLabelAction(*this, *label);
-	if (!m_signal_manager.registerUndoAction(undo_modify)) {
+	// execute the dialog
+	accepted = (dlg->exec() == QDialog::Accepted);
+	if (!accepted) {
+	    // user pressed "cancel"
 	    delete dlg;
-	    return false;
+	    break;
 	}
 
-	// move the label and change the name if possible
-	label->moveTo(dlg->labelPosition());
-	label->rename(dlg->labelName());
+	// if we get here the user pressed "OK"
+	new_pos  = dlg->labelPosition();
+	new_name = dlg->labelName();
 	dlg->saveSettings();
+	delete dlg;
+
+	// check: if there already is a label at the new position
+	// -> ask the user if he wants to overwrite that one
+	if ((new_pos != label.pos()) &&
+	    !m_signal_manager.findLabel(new_pos).isNull())
+	{
+	    int res = Kwave::MessageBox::warningYesNoCancel(this, i18n(
+		"There already is a label at the position "\
+		"you have choosen.\n"\
+		"Do you want to replace it ?"));
+	    if (res == KMessageBox::Yes) {
+		// delete the label at the target position (with undo)
+		Label old = m_signal_manager.findLabel(new_pos);
+		old_index = m_signal_manager.labelIndex(old);
+		break;
+	    }
+	    if (res == KMessageBox::No) {
+		// make another try -> re-enter the dialog
+		continue;
+	    }
+
+	    // cancel -> abort the whole action
+	    accepted = false;
+	    break;
+	} else {
+	    // ok, we can put it there
+	    break;
+	}
+    }
+
+    if (accepted) {
+	// shortcut: abort if nothing has changed
+	if ((new_name == label.name()) && (new_pos == label.pos()))
+	    return false;
+
+	UndoTransactionGuard undo(m_signal_manager, i18n("modify label"));
+
+	// if there is a label at the target position, remove it first
+	if (old_index >= 0) {
+	    m_signal_manager.deleteLabel(old_index, true);
+	    // this might have changed the current index!
+	    index = m_signal_manager.labelIndex(label);
+	}
+
+	UndoModifyLabelAction *undo_modify =
+	    new UndoModifyLabelAction(*this, label);
+	if (!m_signal_manager.registerUndoAction(undo_modify))
+	    return false;
 
 	// now store the label's current position,
 	// for finding it again later
-	undo_modify->setLastPosition(label->pos());
+	undo_modify->setLastPosition(new_pos);
+
+	// modify the label through the signal manager
+	if (!m_signal_manager.modifyLabel(index, new_pos, new_name)) {
+	    // position is already occupied
+	    m_signal_manager.abortUndoTransaction();
+	    return false;
+	}
+
+	// reflect the change in the passed label
+	label.moveTo(new_pos);
+	label.rename(new_name);
 
 	// NOTE: moving might also change the index, so the complete
 	//       markers layer has to be refreshed
-	refreshLayer(LAYER_MARKERS);
+	refreshMarkersLayer();
     }
+    else
+	m_signal_manager.abortUndoTransaction();
 
-    delete dlg;
     return accepted;
 }
 
@@ -2327,7 +2482,11 @@ void SignalWidget::slotSamplesInserted(unsigned int track,
     Q_UNUSED(offset);
     Q_UNUSED(length);
 
-    refreshLayer(LAYER_MARKERS);
+    // length has changed -> update overview
+    emit viewInfo(m_offset, pixels2samples(QWidget::width()-1)+1,
+                  m_signal_manager.length());
+
+    refreshMarkersLayer();
 }
 
 //***************************************************************************
@@ -2340,7 +2499,11 @@ void SignalWidget::slotSamplesDeleted(unsigned int track,
     Q_UNUSED(offset);
     Q_UNUSED(length);
 
-    refreshLayer(LAYER_MARKERS);
+    // length has changed -> update overview
+    emit viewInfo(m_offset, pixels2samples(QWidget::width()-1)+1,
+                  m_signal_manager.length());
+
+    refreshMarkersLayer();
 }
 
 //***************************************************************************
@@ -2370,7 +2533,7 @@ void SignalWidget::startDragging()
 	m_signal_manager.selectedTracks(), first, last);
 
     // create the file info
-    FileInfo info;
+    FileInfo info = m_signal_manager.fileInfo();
     info.setLength(last - first + 1);
     info.setRate(rate);
     info.setBits(bits);
@@ -2414,7 +2577,7 @@ void SignalWidget::dragEnterEvent(QDragEnterEvent *event)
         (event->proposedAction() != Qt::CopyAction))
         return; /* unsupported action */
 
-    if (KwaveFileDrag::canDecode(event->mimeData()))
+    if (KwaveDrag::canDecode(event->mimeData()))
 	event->acceptProposedAction();
 }
 
@@ -2432,13 +2595,14 @@ void SignalWidget::dropEvent(QDropEvent *event)
 
     if (KwaveDrag::canDecode(event->mimeData())) {
 	UndoTransactionGuard undo(m_signal_manager, i18n("drag and drop"));
-	Signal sig;
 	InhibitRepaintGuard inhibit(*this);
 	unsigned int pos = m_offset + pixels2samples(event->pos().x());
 	unsigned int len = 0;
 
 	/** @todo add a converter if rate does not match */
-	if ((len = KwaveDrag::decode(this, event, m_signal_manager, pos))) {
+	if ((len = KwaveDrag::decode(this, event->mimeData(),
+	    m_signal_manager, pos)))
+	{
 	    /**
 	     * @todo after the drop operation: enter the new file info into
 	     * the signal manager if our own file was empty
@@ -2497,8 +2661,10 @@ void SignalWidget::dragMoveEvent(QDragMoveEvent* event)
 	// transform to pixel coordinates
 	left  = samples2pixels(left - m_offset);
 	right = samples2pixels(right - m_offset);
-	if (right >= (unsigned int)(m_width)) right=m_width-1;
-	if (left > right) left = right;
+	if (right >= static_cast<unsigned int>(m_width))
+	    right=m_width-1;
+	if (left > right)
+	    left = right;
 
 	r.setLeft(left);
 	r.setRight(right);
