@@ -15,7 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <Decoder.h>
+#include "config.h"
+#include "Decoder.h"
 
 //***************************************************************************
 Decoder::Decoder()
@@ -23,6 +24,11 @@ Decoder::Decoder()
 {
 }
 
+//***************************************************************************
+Decoder::~Decoder()
+{
+}
+
 //***************************************************************************
 #include "Decoder.moc"
 //***************************************************************************
