@@ -26,14 +26,25 @@
 
 //***************************************************************************
 namespace Kwave {
+
+    //***********************************************************************
+    static void _connect_one_by_one(
+	Kwave::StreamObject *source, const char *output,
+	Kwave::StreamObject *sink,   const char *input)
+    {
+	QObject::connect(
+	    source, output,
+	    sink,   input,
+	    Qt::DirectConnection);
+    }
+
+    //***********************************************************************
     bool connect(Kwave::StreamObject &source, const QString &output,
 	         Kwave::StreamObject &sink,   const QString &input)
     {
 	unsigned int src_tracks = source.tracks();
 	unsigned int dst_tracks = sink.tracks();
 
-	Q_ASSERT(src_tracks);
-	Q_ASSERT(dst_tracks);
 	if (!src_tracks || !dst_tracks)
 	    return false;
 
@@ -44,16 +55,18 @@ namespace Kwave {
 
 	if ((src_tracks == 1) && (dst_tracks == 1)) {
 	    // 1 output -> 1 input
-	    QObject::connect(source[0], output.toAscii(),
-	                     sink[0], input.toAscii());
+	    _connect_one_by_one(
+		source[0], output.toAscii(),
+		sink[0], input.toAscii());
 	} else if ((src_tracks == 1) && (dst_tracks > 1)) {
 	    // 1 output -> N inputs
 	    for (unsigned int track=0; track < dst_tracks; track++) {
 		Kwave::StreamObject *sink_n = sink[track];
 		Q_ASSERT(sink_n);
 		if (!sink_n) return false;
-		QObject::connect(source[0], output.toAscii(),
-		                 sink_n, input.toAscii());
+		_connect_one_by_one(
+		    source[0], output.toAscii(),
+		    sink_n, input.toAscii());
 	    }
 	} else if (src_tracks == dst_tracks) {
 	    // N outputs -> N inputs
@@ -64,8 +77,9 @@ namespace Kwave {
 		Q_ASSERT(sink_n);
 		if (!source_n) return false;
 		if (!sink_n)   return false;
-		QObject::connect(source_n, output.toAscii(),
-		                 sink_n, input.toAscii());
+		_connect_one_by_one(
+		    source_n, output.toAscii(),
+		    sink_n, input.toAscii());
 	    }
 	} else {
 	    qWarning("invalid source/sink combination, %d:%d tracks",
