@@ -28,7 +28,6 @@
 #include <kdemacros.h>
 
 class QMimeData;
-class QMimeSource;
 class QWidget;
 
 class FileInfo;
@@ -55,20 +54,6 @@ public:
     /** Destructor */
     virtual ~KwaveDrag();
 
-    /**
-     * Returns one entry in the list of supported formats.
-     * @param i index of the format [0...n]
-     * @return name of the format or null
-     */
-    virtual const char *format(int i) const;
-
-    /**
-     * Returns the encoded data as a byte array.
-     * @param format the mime type of the required data
-     * @return byte array with wav encoded data
-     */
-    virtual QByteArray encodedData(const char *format) const;
-
     /**
      * Encodes wave data received from a MultiTrackReader into a byte
      * array that is compatible with the format of a wav file.
@@ -90,14 +75,9 @@ public:
      * @param sig signal that receives the mime data
      * @return number of decoded samples if successful, zero if failed
      */
-    static unsigned int decode(QWidget *widget, const QMimeSource *e,
+    static unsigned int decode(QWidget *widget, const QMimeData *e,
                                SignalManager &sig, unsigned int pos);
 
-private:
-
-    /** simple array for storage of the wave data */
-    QByteArray m_data;
-
 };
 
 #endif /* _KWAVE_DRAG_H_ */
