@@ -1,5 +1,5 @@
 /***************************************************************************
-        KwavePlugin.cpp  -  New Interface for Kwave plugins
+        KwavePlugin.cpp  -  base class of all Kwave plugins
                              -------------------
     begin                : Thu Jul 27 2000
     copyright            : (C) 2000 by Thomas Eschenbacher
@@ -23,13 +23,16 @@
 #include <dlfcn.h>
 #include <sched.h>
 
-#include <QWidget>
+#include <QProgressDialog>
+#include <QTime>
 #include <QVector>
+#include <QWidget>
 
 #include <kapplication.h>
 #include <kglobal.h>
 #include <klocale.h>
 
+#include "libkwave/ConfirmCancelProxy.h"
 #include "libkwave/KwavePlugin.h"
 #include "libkwave/MultiTrackReader.h"
 #include "libkwave/MultiTrackWriter.h"
@@ -63,10 +66,14 @@
  */
 
 //***************************************************************************
-KwavePlugin::KwavePlugin(const PluginContext &c)
+Kwave::Plugin::Plugin(const PluginContext &c)
     :m_context(c),
      m_thread(0),
      m_thread_lock(),
+     m_progress_enabled(true),
+     m_stop(false),
+     m_progress(0),
+     m_confirm_cancel(0),
      m_usage_count(0),
      m_usage_lock()
 {
@@ -74,7 +81,7 @@ KwavePlugin::KwavePlugin(const PluginContext &c)
 }
 
 //***************************************************************************
-KwavePlugin::~KwavePlugin()
+Kwave::Plugin::~Plugin()
 {
     // inform our owner that we close. This allows the plugin to
     // delete itself
@@ -88,39 +95,42 @@ KwavePlugin::~KwavePlugin()
 	    if (m_thread->isRunning()) m_thread->wait(1000);
 	    if (m_thread->isRunning()) {
 		// unable to stop the thread
-		qWarning("KwavePlugin::stop(): stale thread !");
+		qWarning("Kwave::Plugin::stop(): stale thread !");
 	    }
 	    delete m_thread;
 	    m_thread = 0;
 	}
     }
+
+    if (m_confirm_cancel) delete m_confirm_cancel;
+    if (m_progress)       delete m_progress;
 }
 
 //***************************************************************************
-const QString &KwavePlugin::name()
+const QString &Kwave::Plugin::name()
 {
     return m_context.m_name;
 }
 
 //***************************************************************************
-const QString &KwavePlugin::version()
+const QString &Kwave::Plugin::version()
 {
     return m_context.m_version;
 }
 
 //***************************************************************************
-const QString &KwavePlugin::author()
+const QString &Kwave::Plugin::author()
 {
     return m_context.m_author;
 }
 
 //***************************************************************************
-void KwavePlugin::load(QStringList &)
+void Kwave::Plugin::load(QStringList &)
 {
 }
 
 //***************************************************************************
-QStringList *KwavePlugin::setup(QStringList &)
+QStringList *Kwave::Plugin::setup(QStringList &)
 {
     QStringList *result = new QStringList();
     Q_ASSERT(result);
@@ -128,18 +138,68 @@ QStringList *KwavePlugin::setup(QStringList &)
 }
 
 //***************************************************************************
-int KwavePlugin::start(QStringList &)
+int Kwave::Plugin::start(QStringList &)
 {
     QMutexLocker lock(&m_thread_lock);
+    m_stop = false;
+
+    Q_ASSERT(!m_progress);
+    Q_ASSERT(!m_confirm_cancel);
+
+    // check: start() must be called from the GUI thread only!
+    Q_ASSERT(this->thread() == QThread::currentThread());
+    Q_ASSERT(this->thread() == qApp->thread());
+
+    // create a progress dialog for processing mode (not used for pre-listen)
+    if (m_progress_enabled) {
+	m_progress = new QProgressDialog(parentWidget());
+	Q_ASSERT(m_progress);
+    }
+
+    // set up the progress dialog when in processing (not pre-listen) mode
+    if (m_progress_enabled && m_progress) {
+	unsigned int first, last;
+	unsigned int tracks = selectedTracks().count();
+
+	selection(&first, &last, true);
+	m_progress->setModal(true);
+	m_progress->setVisible(false);
+	m_progress->setMinimumDuration(2000);
+	m_progress->setAutoClose(true);
+	m_progress->setMaximum((last - first + 1) * tracks);
+	m_progress->setValue(0);
+	m_progress->setLabelText(progressText());
+	int h = m_progress->sizeHint().height();
+	int w = m_progress->sizeHint().height();
+	if (w < 4*h) w = 4*h;
+	m_progress->setFixedSize(w, h);
+
+	// use a "proxy" that asks for confirmation of cancel
+	m_confirm_cancel = new ConfirmCancelProxy(m_progress,
+		0, 0, this, SLOT(cancel()));
+	Q_ASSERT(m_confirm_cancel);
+	connect(m_progress,      SIGNAL(canceled()),
+		m_confirm_cancel, SLOT(cancel()));
+	m_progress->setVisible(true);
+    }
+
     return 0;
 }
 
 //***************************************************************************
-int KwavePlugin::stop()
+QString Kwave::Plugin::progressText()
 {
+    return i18n("running plugin '%1' ...", name());
+}
+
+//***************************************************************************
+int Kwave::Plugin::stop()
+{
+    cancel();
+
     if (m_thread && m_thread->isRunning() &&
 	(QThread::currentThread() == m_thread)) {
-	qWarning("KwavePlugin::stop(): plugin '%s' called stop() from "\
+	qWarning("Kwave::Plugin::stop(): plugin '%s' called stop() from "\
 	         "within it's own worker thread (from run() ?). "\
 	         "This would produce a deadlock, dear %s, PLEASE FIX THIS !",
 	         name().toLocal8Bit().data(),
@@ -147,7 +207,8 @@ int KwavePlugin::stop()
 
 #ifdef DEBUG
 	qDebug("pthread_self()=%p, tid=%p",
-	       QThread::currentThread(), m_thread);
+	       reinterpret_cast<void *>(QThread::currentThread()),
+	       reinterpret_cast<void *>(m_thread));
 	void *buf[256];
 	size_t n = backtrace(buf, 256);
 	backtrace_symbols_fd(buf, n, 2);
@@ -163,7 +224,7 @@ int KwavePlugin::stop()
 	    if (m_thread->isRunning()) m_thread->wait(1000);
 	    if (m_thread->isRunning()) {
 		// unable to stop the thread
-		qWarning("KwavePlugin::stop(): stale thread !");
+		qWarning("Kwave::Plugin::stop(): stale thread !");
 	    }
 	    delete m_thread;
 	    m_thread = 0;
@@ -173,9 +234,34 @@ int KwavePlugin::stop()
 }
 
 //***************************************************************************
-int KwavePlugin::execute(QStringList &params)
+void Kwave::Plugin::setProgressDialogEnabled(bool enable)
+{
+    m_progress_enabled = enable;
+}
+
+//***************************************************************************
+void Kwave::Plugin::updateProgress(unsigned int progress)
+{
+//     qDebug("Kwave::Plugin::updateProgress(%u)", progress);
+
+    // check: this must be called from the GUI thread only!
+    Q_ASSERT(this->thread() == QThread::currentThread());
+    Q_ASSERT(this->thread() == qApp->thread());
+
+    if (m_progress) m_progress->setValue(progress);
+}
+
+//***************************************************************************
+void Kwave::Plugin::cancel()
+{
+    m_stop = true;
+}
+
+//***************************************************************************
+int Kwave::Plugin::execute(QStringList &params)
 {
     QMutexLocker lock(&m_thread_lock);
+    m_stop = false;
 
     m_thread = new Kwave::PluginWorkerThread(this, params);
     Q_ASSERT(m_thread);
@@ -188,33 +274,43 @@ int KwavePlugin::execute(QStringList &params)
 }
 
 //***************************************************************************
-bool KwavePlugin::isRunning()
+bool Kwave::Plugin::isRunning()
 {
     return (m_thread) && m_thread->isRunning();
 }
 
 //***************************************************************************
-void KwavePlugin::run(QStringList)
+void Kwave::Plugin::run(QStringList)
 {
 }
 
 //***************************************************************************
-void KwavePlugin::run_wrapper(QStringList params)
+void Kwave::Plugin::run_wrapper(QStringList params)
 {
     // signal that we are running
     emit sigRunning(this);
 
+    // start time measurement
+    QTime t;
+    t.start();
+
     // call the plugin's run function in this worker thread context
     run(params);
 
+    // evaluate the elapsed time
+    double seconds = static_cast<double>(t.elapsed()) * 1E-3;
+    qDebug("plugin %s done, running for %0.03g seconds",
+	name().toLocal8Bit().data(), seconds);
+
     // emit the "done" signal
     emit sigDone(this);
 
+    m_stop = false;
     release();
 }
 
 //***************************************************************************
-void KwavePlugin::close()
+void Kwave::Plugin::close()
 {
     // only call stop() if we are NOT in the worker thread / run function !
     if (m_thread && m_thread->isRunning() &&
@@ -225,14 +321,14 @@ void KwavePlugin::close()
 }
 
 //***************************************************************************
-void KwavePlugin::use()
+void Kwave::Plugin::use()
 {
     QMutexLocker lock(&m_usage_lock);
     m_usage_count++;
 }
 
 //***************************************************************************
-void KwavePlugin::release()
+void Kwave::Plugin::release()
 {
     bool finished = false;
 
@@ -249,55 +345,55 @@ void KwavePlugin::release()
 }
 
 //***************************************************************************
-PluginManager &KwavePlugin::manager()
+PluginManager &Kwave::Plugin::manager()
 {
     return m_context.m_plugin_manager;
 }
 
 //***************************************************************************
-SignalManager &KwavePlugin::signalManager()
+SignalManager &Kwave::Plugin::signalManager()
 {
     return manager().signalManager();
 }
 
 //***************************************************************************
-QWidget *KwavePlugin::parentWidget()
+QWidget *Kwave::Plugin::parentWidget()
 {
     return manager().parentWidget();
 }
 
 //***************************************************************************
-FileInfo &KwavePlugin::fileInfo()
+FileInfo &Kwave::Plugin::fileInfo()
 {
     return manager().fileInfo();
 }
 
 //***************************************************************************
-QString KwavePlugin::signalName()
+QString Kwave::Plugin::signalName()
 {
     return signalManager().signalName();
 }
 
 //***************************************************************************
-unsigned int KwavePlugin::signalLength()
+unsigned int Kwave::Plugin::signalLength()
 {
     return manager().signalLength();
 }
 
 //***************************************************************************
-qreal KwavePlugin::signalRate()
+qreal Kwave::Plugin::signalRate()
 {
     return manager().signalRate();
 }
 
 //***************************************************************************
-const QList<unsigned int> KwavePlugin::selectedTracks()
+const QList<unsigned int> Kwave::Plugin::selectedTracks()
 {
     return manager().selectedTracks();
 }
 
 //***************************************************************************
-unsigned int KwavePlugin::selection(unsigned int *left, unsigned int *right,
+unsigned int Kwave::Plugin::selection(unsigned int *left, unsigned int *right,
                                     bool expand_if_empty)
 {
     int l = manager().selectionStart();
@@ -315,31 +411,31 @@ unsigned int KwavePlugin::selection(unsigned int *left, unsigned int *right,
 }
 
 //***************************************************************************
-void KwavePlugin::selectRange(unsigned int offset, unsigned int length)
+void Kwave::Plugin::selectRange(unsigned int offset, unsigned int length)
 {
     manager().selectRange(offset, length);
 }
 
 //***************************************************************************
-void KwavePlugin::yield()
+void Kwave::Plugin::yield()
 {
     pthread_testcancel();
     sched_yield();
 }
 
 //***************************************************************************
-void *KwavePlugin::handle()
+void *Kwave::Plugin::handle()
 {
     return m_context.m_handle;
 }
 
 //***************************************************************************
-QString KwavePlugin::zoom2string(qreal percent)
+QString Kwave::Plugin::zoom2string(qreal percent)
 {
     QString result = "";
 
     if (percent < 1.0) {
-	int digits = (int)ceil(1.0 - log10(percent));
+	int digits = static_cast<int>(ceil(1.0 - log10(percent)));
 	QString format;
 	format = "%0."+format.setNum(digits)+"f %%";
 	result = format.sprintf(format.toUtf8(), percent);
@@ -348,13 +444,14 @@ QString KwavePlugin::zoom2string(qreal percent)
     } else if (percent < 1000.0) {
 	result = result.sprintf("%0.0f %%", percent);
     } else {
-	result = result.sprintf("x %d", (int)rint(percent / 100.0));
+	result = result.sprintf("x %d",
+	    static_cast<int>(rint(percent / 100.0)));
     }
     return result;
 }
 
 //***************************************************************************
-QString KwavePlugin::ms2string(qreal ms, int precision)
+QString Kwave::Plugin::ms2string(qreal ms, int precision)
 {
     char buf[128];
     int bufsize = 128;
@@ -362,7 +459,7 @@ QString KwavePlugin::ms2string(qreal ms, int precision)
     if (ms < 1.0) {
 	char format[128];
 	// limit precision, use 0.0 for exact zero
-	int digits = (ms != 0.0) ? (int)ceil(1.0 - log10(ms)) : 1;
+	int digits = (ms != 0.0) ? static_cast<int>(ceil(1.0 - log10(ms))) : 1;
 	if ( (digits < 0) || (digits > precision)) digits = precision;
 
 	snprintf(format, sizeof(format), "%%0.%df ms", digits);
@@ -370,12 +467,13 @@ QString KwavePlugin::ms2string(qreal ms, int precision)
     } else if (ms < 1000.0) {
 	snprintf(buf, bufsize, "%0.1f ms", ms);
     } else {
-	int s = (int)round(ms / 1000.0);
-	int m = (int)floor(s / 60.0);
+	int s = static_cast<int>(round(ms / 1000.0));
+	int m = static_cast<int>(floor(s / 60.0));
 
 	if (m < 1) {
 	    char format[128];
-	    int digits = (int)ceil((qreal)(precision+1) - log10(ms));
+	    int digits = static_cast<int>(
+		ceil(static_cast<qreal>(precision+1) - log10(ms)));
 	    snprintf(format, sizeof(format), "%%0.%df s", digits);
 	    snprintf(buf, bufsize, format, ms / 1000.0);
 	} else {
@@ -388,7 +486,7 @@ QString KwavePlugin::ms2string(qreal ms, int precision)
 }
 
 //***************************************************************************
-QString KwavePlugin::dottedNumber(unsigned int number)
+QString Kwave::Plugin::dottedNumber(unsigned int number)
 {
     const QString num = QString::number(number);
     QString dotted = "";
@@ -402,7 +500,7 @@ QString KwavePlugin::dottedNumber(unsigned int number)
 }
 
 //***************************************************************************
-void KwavePlugin::emitCommand(const QString &command)
+void Kwave::Plugin::emitCommand(const QString &command)
 {
     manager().enqueueCommand(command);
 }
