@@ -28,6 +28,10 @@
 class KDE_EXPORT Label
 {
 public:
+
+    /** Default constructor, creates an empty label */
+    Label();
+
     /**
      * Constructor
      *
@@ -57,10 +61,13 @@ public:
     /** returns the name of the string */
     virtual QString name() const;
 
+    /** returns true if this is an empty label */
+    virtual bool isNull() const;
+
     /** less-than operator, needed for sorting the list */
     inline bool operator < (const Label &other) const {
 	return (pos() < other.pos());
-    };
+    }
 
     /** equal operator */
     inline bool operator == (const Label &other) const {
@@ -69,13 +76,17 @@ public:
 
 private:
 
+    /** internal container class with label data */
     class LabelData: public QSharedData {
     public:
 
+	/** constructor */
 	LabelData();
 
+	/** copy constructor */
 	LabelData(const LabelData &other);
 
+	/** destructor */
 	virtual ~LabelData();
 
 	/** position of the label [samples] */
@@ -85,6 +96,7 @@ private:
 	QString m_name;
     };
 
+    /** pointer to the shared label data */
     QSharedDataPointer<LabelData> m_data;
 
 };
