@@ -19,16 +19,23 @@
 #define _SAMPLE_FIFO_H_
 
 #include "config.h"
-#include <qvaluevector.h>
-#include <qmutex.h>
+
+#include <QMutex>
+#include <QQueue>
+
+#include <kdemacros.h>
+
 #include "libkwave/KwaveSampleArray.h"
 
-class SampleFIFO
+class KDE_EXPORT SampleFIFO
 {
 public:
     /** Constructor */
     SampleFIFO();
 
+    /** copy constructor */
+    SampleFIFO(const SampleFIFO &other);
+
     /** Destructor */
     virtual ~SampleFIFO();
 
@@ -59,10 +66,29 @@ public:
      */
     virtual unsigned int length();
 
+    /**
+     * sets the maximum size of the content
+     */
+    virtual void setSize(unsigned int size);
+
+    /**
+     * discards all superflous content until the size
+     * condition is met.
+     */
+    virtual void crop();
+
+private:
+
+    /** internal version of length(), without locking */
+    unsigned int unlockedLength();
+
 private:
 
     /** list of buffers with sample data */
-    QValueVector<Kwave::SampleArray> m_buffer;
+    QQueue<Kwave::SampleArray> m_buffer;
+
+    /** maximum number of samples of the content */
+    unsigned int m_size;
 
     /**
      * number of samples that have already been read out
