@@ -18,6 +18,8 @@
 
 #include "config.h"
 
+#include <QApplication>
+
 #include "libkwave/memcpy.h"
 #include "libkwave/Sample.h"
 #include "libkwave/SampleReader.h"
@@ -29,19 +31,26 @@
 // define this for using only slow Qt array functions
 // #define STRICTLY_QT
 
+/** minimum time between emitting the "progress()" signal [ms] */
+#define MIN_PROGRESS_INTERVAL 500
+
 //***************************************************************************
 SampleReader::SampleReader(Track &track,
                            unsigned int left, unsigned int right)
     :m_track(track),
-    m_src_position(left), m_first(left), m_last(right),
-    m_buffer(blockSize()),
-    m_buffer_used(0), m_buffer_position(0)
+     m_src_position(left), m_first(left), m_last(right),
+     m_buffer(blockSize()),
+     m_buffer_used(0), m_buffer_position(0),
+     m_progress_time()
 {
+    m_track.use();
+    m_progress_time.start();
 }
 
 //***************************************************************************
 SampleReader::~SampleReader()
 {
+    m_track.release();
 }
 
 //***************************************************************************
@@ -75,7 +84,9 @@ void SampleReader::fillBuffer()
     if (eof()) return;
 
     unsigned int rest = m_buffer.size();/* - m_buffer_used (is 0) */
-    if (m_src_position+rest >= m_last) rest = (m_last-m_src_position+1);
+    if (m_src_position + rest > m_last) rest = (m_last - m_src_position + 1);
+    Q_ASSERT(rest <= m_buffer.size());
+    if (rest > m_buffer.size()) rest = m_buffer.size();
     Q_ASSERT(rest);
 
     unsigned int len = m_track.readSamples(m_src_position, m_buffer, 0, rest);
@@ -84,7 +95,19 @@ void SampleReader::fillBuffer()
     m_src_position += len;
     rest           -= len;
 
-    emit proceeded();
+    // inform others that we proceeded
+    if (m_progress_time.elapsed() > MIN_PROGRESS_INTERVAL) {
+	m_progress_time.restart();
+	emit proceeded();
+	QApplication::sendPostedEvents();
+    }
+}
+
+//***************************************************************************
+void SampleReader::minMax(unsigned int first, unsigned int last,
+                          sample_t &min, sample_t &max)
+{
+    m_track.minMax(first, last, min, max);
 }
 
 //***************************************************************************
@@ -145,7 +168,11 @@ unsigned int SampleReader::read(Kwave::SampleArray &buffer,
     m_src_position += len;
     count += len;
 
-    emit proceeded();
+    // inform others that we proceeded
+    if (m_progress_time.elapsed() > MIN_PROGRESS_INTERVAL) {
+	m_progress_time.restart();
+	emit proceeded();
+    }
     return count;
 }
 
