@@ -17,6 +17,8 @@
 
 #include "config.h"
 
+#include <QApplication>
+
 #include "libkwave/memcpy.h"
 #include "libkwave/InsertMode.h"
 #include "libkwave/Sample.h"
@@ -28,20 +30,27 @@
 /** size of m_buffer in samples */
 #define BUFFER_SIZE (256*1024)
 
+/** minimum time between emitting the "progress()" signal [ms] */
+#define MIN_PROGRESS_INTERVAL 500
+
 //***************************************************************************
 SampleWriter::SampleWriter(Track &track, InsertMode mode,
     unsigned int left, unsigned int right)
     :Kwave::SampleSink(),
      m_first(left), m_last(right), m_mode(mode), m_track(track),
      m_position(left),
-     m_buffer(BUFFER_SIZE), m_buffer_used(0)
+     m_buffer(BUFFER_SIZE), m_buffer_size(BUFFER_SIZE), m_buffer_used(0),
+     m_progress_time()
 {
+    m_track.use();
+    m_progress_time.start();
 }
 
 //***************************************************************************
 SampleWriter::~SampleWriter()
 {
     flush();
+    m_track.release();
     Q_ASSERT(m_position <= m_last+1);
 
     // inform others that we proceeded
@@ -53,12 +62,12 @@ SampleWriter &SampleWriter::operator << (const Kwave::SampleArray &samples)
 {
     unsigned int count = samples.size();
 
-    if (m_buffer_used + count < m_buffer.size()) {
+    if (m_buffer_used + count < m_buffer_size) {
 	// append to the internal buffer if there is still some room
 	MEMCPY(&(m_buffer[m_buffer_used]), &(samples[0]),
 	       count * sizeof(sample_t));
 	m_buffer_used += count;
-	if (m_buffer_used >= m_buffer.size()) flush();
+	if (m_buffer_used >= m_buffer_size) flush();
     } else {
 	// first flush the single-sample buffer before doing block operation
 	if (m_buffer_used) flush();
@@ -75,7 +84,7 @@ SampleWriter &SampleWriter::operator << (const Kwave::SampleArray &samples)
 SampleWriter &SampleWriter::operator << (const sample_t &sample)
 {
     m_buffer[m_buffer_used++] = sample;
-    if (m_buffer_used >= m_buffer.size()) flush();
+    if (m_buffer_used >= m_buffer_size) flush();
     return *this;
 }
 
@@ -85,7 +94,7 @@ SampleWriter &SampleWriter::operator << (SampleReader &reader)
     if (m_buffer_used) flush();
 
     // transfer data, using our internal buffer
-    unsigned int buflen = m_buffer.size();
+    unsigned int buflen = m_buffer_size;
     while (!reader.eof() && (m_position <= m_last)) {
 	if (m_position+buflen-1 > m_last) buflen = (m_last-m_position)+1;
 
@@ -130,7 +139,11 @@ bool SampleWriter::flush(const Kwave::SampleArray &buffer,
     count = 0;
 
     // inform others that we proceeded
-    emit proceeded();
+    if (m_progress_time.elapsed() > MIN_PROGRESS_INTERVAL) {
+	m_progress_time.restart();
+	emit proceeded();
+	QApplication::sendPostedEvents();
+    }
 
     return true;
 }
@@ -149,7 +162,7 @@ SampleWriter &flush(SampleWriter &s)
 }
 
 //***************************************************************************
-void SampleWriter::input(Kwave::SampleArray &data)
+void SampleWriter::input(Kwave::SampleArray data)
 {
     if (data.size()) (*this) << data;
 }
