@@ -23,6 +23,17 @@ Selection::Selection(unsigned int offset, unsigned int length)
 {
 }
 
+//***************************************************************************
+Selection::Selection(const Selection &other)
+    :QObject(), m_offset(other.offset()), m_length(other.length())
+{
+}
+
+//***************************************************************************
+Selection::~Selection()
+{
+}
+
 //***************************************************************************
 #include "Selection.moc"
 //***************************************************************************
