@@ -24,6 +24,7 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QMutexLocker>
+#include <QMutableListIterator>
 
 #include <kaboutdata.h>
 #include <kapplication.h>
@@ -39,11 +40,13 @@
 #include "libkwave/Encoder.h"
 #include "libkwave/FileProgress.h"
 #include "libkwave/InsertMode.h"
+#include "libkwave/MemoryManager.h"
 #include "libkwave/MessageBox.h"
 #include "libkwave/MultiTrackReader.h"
 #include "libkwave/MultiTrackWriter.h"
 #include "libkwave/Parser.h"
 #include "libkwave/Sample.h"
+#include "libkwave/SampleFormat.h"
 #include "libkwave/SampleReader.h"
 #include "libkwave/SampleWriter.h"
 #include "libkwave/Signal.h"
@@ -62,9 +65,6 @@
 #include "libkwave/undo/UndoSelection.h"
 #include "libkwave/undo/UndoTransaction.h"
 
-#define min(x,y) (((x)<(y)) ? (x) : (y))
-#define max(x,y) (((x)>(y)) ? (x) : (y))
-
 #define CASE_COMMAND(x) } else if (parser.command() == x) {
 
 //***************************************************************************
@@ -77,6 +77,8 @@ SignalManager::SignalManager(QWidget *parent)
     m_modified_enabled(true),
     m_signal(),
     m_selection(0,0),
+    m_last_selection(0,0),
+    m_last_track_selection(),
     m_last_length(0),
     m_playback_controller(),
     m_undo_enabled(false),
@@ -84,9 +86,7 @@ SignalManager::SignalManager(QWidget *parent)
     m_redo_buffer(),
     m_undo_transaction(0),
     m_undo_transaction_level(0),
-    m_undo_transaction_lock(),
-    m_undo_limit(64*1024*1024), // 64 MB (for testing) ###
-    /** @todo the undo memory limit should be user-configurable. */
+    m_undo_transaction_lock(QMutex::Recursive),
     m_file_info()
 {
     // connect to the track's signals
@@ -145,7 +145,8 @@ int SignalManager::loadFile(const KUrl &url)
 	// enter the filename/mimetype and size into the decoder
 	QFileInfo fi(src);
 	decoder->info().set(INF_FILENAME, fi.absoluteFilePath());
-	decoder->info().set(INF_FILESIZE, (unsigned int)src.size());
+	decoder->info().set(INF_FILESIZE,
+	    static_cast<unsigned int>(src.size()));
 	decoder->info().set(INF_MIMETYPE, mimetype);
 
 	// get the file info from the decoder
@@ -252,8 +253,9 @@ int SignalManager::loadFile(const KUrl &url)
 	delete decoder;
     }
 
-    // remember the last length
+    // remember the last length and selection
     m_last_length = length();
+    rememberCurrentSelection();
 
     // from now on, undo is enabled
     enableUndo();
@@ -385,7 +387,8 @@ int SignalManager::save(const KUrl &url, bool selection)
 	    m_file_info.tracks());
 	Q_ASSERT(dialog);
 	QObject::connect(&src,   SIGNAL(progress(unsigned int)),
-	                 dialog, SLOT(setValue(unsigned int)));
+	                 dialog, SLOT(setValue(unsigned int)),
+	                 Qt::QueuedConnection);
 	QObject::connect(dialog, SIGNAL(canceled()),
 	                 &src,   SLOT(cancel()));
 
@@ -398,15 +401,16 @@ int SignalManager::save(const KUrl &url, bool selection)
 	    FileInfo info = m_file_info;
 
 	    LabelList &labels = info.labels();
-	    foreach (Label *label, labels) {
-		if (!label) continue;
-		unsigned int pos = label->pos();
+	    QMutableListIterator<Label> it(labels);
+	    while (it.hasNext()) {
+		Label &label = it.next();
+		unsigned int pos = label.pos();
 		if ((pos < ofs) || (pos >= ofs + len)) {
 		    // out of the selected area -> remove
-		    labels.removeAll(label);
+		    it.remove();
 		} else {
 		    // move label left
-		    label->moveTo(pos - ofs);
+		    label.moveTo(pos - ofs);
 		}
 	    }
 
@@ -467,6 +471,13 @@ void SignalManager::newSignal(unsigned int samples, double rate,
     m_file_info.setRate(rate);
     m_file_info.setBits(bits);
 
+    // use "unsigned" sample formats per default for <= 8 bits/sample formats
+    if (bits <= 8) {
+	const SampleFormat format(SampleFormat::Unsigned);
+	m_file_info.set(INF_SAMPLE_FORMAT, QVariant(format.toInt()));
+    }
+    emit labelsChanged(labels());
+
     // now the signal is considered not to be empty
     m_closed = false;
     m_empty = false;
@@ -478,6 +489,7 @@ void SignalManager::newSignal(unsigned int samples, double rate,
     // remember the last length
     m_last_length = samples;
     m_file_info.setLength(length());
+    rememberCurrentSelection();
 
     // from now on, undo is enabled
     enableUndo();
@@ -498,7 +510,7 @@ void SignalManager::close()
     // undo will be re-enabled when a signal is loaded or created
     disableUndo();
 
-    // for safety: flush all undo/redo buffer
+    // for safety: flush all undo/redo buffers
     flushUndoBuffers();
     flushRedoBuffer();
 
@@ -509,6 +521,8 @@ void SignalManager::close()
 
     m_closed = true;
     m_selection.select(0,0);
+    rememberCurrentSelection();
+
     emitStatusInfo();
 }
 
@@ -574,12 +588,11 @@ SampleWriter *SignalManager::openSampleWriter(unsigned int track,
     UndoAction *undo = 0;
     switch (mode) {
 	case Append:
-	    qDebug("SignalManager::openSampleWriter(): "\
-	           "NO UNDO FOR APPEND YET !");
-	    abortUndoTransaction();
-	    break;
-	case Insert:
-	    undo = new UndoInsertAction(track, left, right-left+1);
+	case Insert: {
+	    QList<unsigned int> track_list;
+	    track_list.append(track);
+	    undo = new UndoInsertAction(
+		m_parent_widget, track_list, left, right-left+1);
 	    if (undo) {
 		QObject::connect(
 		    writer,
@@ -588,6 +601,7 @@ SampleWriter *SignalManager::openSampleWriter(unsigned int track,
 		    SLOT(setLength(unsigned int)));
 	    }
 	    break;
+	}
 	case Overwrite:
 	    undo = new UndoModifyAction(track, left, right-left+1);
 	    break;
@@ -610,7 +624,6 @@ bool SignalManager::executeCommand(const QString &command)
 {
     unsigned int offset = m_selection.offset();
     unsigned int length = m_selection.length();
-    double rate = m_file_info.rate();
 
     if (!command.length()) return true;
     Parser parser(command);
@@ -620,16 +633,6 @@ bool SignalManager::executeCommand(const QString &command)
 	undo();
     CASE_COMMAND("redo")
 	redo();
-    CASE_COMMAND("copy")
-	ClipBoard &clip = ClipBoard::instance();
-	clip.copy(m_signal, selectedTracks(), offset, length, rate);
-    CASE_COMMAND("paste")
-	paste(ClipBoard::instance(), offset, length);
-    CASE_COMMAND("cut")
-	ClipBoard &clip = ClipBoard::instance();
-	clip.copy(m_signal, selectedTracks(), offset, length, rate);
-	UndoTransactionGuard undo(*this, i18n("cut"));
-	deleteRange(offset, length);
     CASE_COMMAND("crop")
 	UndoTransactionGuard undo(*this, i18n("crop"));
 	unsigned int rest = this->length() - offset;
@@ -687,41 +690,6 @@ bool SignalManager::executeCommand(const QString &command)
     return true;
 }
 
-//***************************************************************************
-void SignalManager::paste(ClipBoard &clipboard, unsigned int offset,
-                          unsigned int length)
-{
-    QList<unsigned int> selected_tracks = selectedTracks();
-    if (clipboard.isEmpty()) return;
-    if (!selected_tracks.size()) return;
-
-    UndoTransactionGuard u(*this, i18n("paste"));
-
-    // delete the current selection (with undo)
-    if (length <= 1) length = 0; // do not paste single samples !
-    if (length && !deleteRange(offset, length))
-	return;
-
-    // if the signal has no tracks, create new ones
-    if (!tracks()) {
-	unsigned int missing = clipboard.tracks();
-	qDebug("SignalManager::paste(): appending %u tracks", missing);
-	while (missing--) appendTrack();
-    }
-
-    // open a stream into the signal
-    MultiTrackWriter dst(*this, selectedTracks(), Insert,
-                         offset, offset+clipboard.length()-1);
-    if (static_cast<int>(dst.tracks()) != selectedTracks().count())
-	return;
-
-    // transfer the content
-    clipboard.paste(dst);
-
-    // set the selection to the inserted range
-    selectRange(offset, clipboard.length());
-}
-
 //***************************************************************************
 void SignalManager::appendTrack()
 {
@@ -799,11 +767,12 @@ void SignalManager::slotSamplesInserted(unsigned int track,
 
     // only adjust the labels once per operation
     if (track == selectedTracks().at(0)) {
-	foreach (Label *label, labels()) {
-	    if (!label) continue;
-	    unsigned int pos = label->pos();
+	QMutableListIterator<Label> it(labels());
+	while (it.hasNext()) {
+	    Label &label = it.next();
+	    unsigned int pos = label.pos();
 	    if (pos >= offset) {
-		label->moveTo(pos + length);
+		label.moveTo(pos + length);
 	    }
 	}
     }
@@ -821,21 +790,6 @@ void SignalManager::slotSamplesDeleted(unsigned int track,
 
     setModified(true);
 
-    // only adjust the labels once per operation
-    if (track == selectedTracks().at(0)) {
-	foreach (Label *label, labels()) {
-	    if (!label) continue;
-	    unsigned int pos = label->pos();
-	    if (pos >= offset + length) {
-		// move label left
-		label->moveTo(pos - length);
-	    } else if ((pos >= offset) && (pos < offset+length)) {
-		// delete the label
-		deleteLabel(labelIndex(label), true);
-	    }
-	}
-    }
-
     emit sigSamplesDeleted(track, offset, length);
     emitStatusInfo();
 }
@@ -867,10 +821,8 @@ bool SignalManager::deleteRange(unsigned int offset, unsigned int length,
     // first store undo data for all tracks
     unsigned int track;
     if (m_undo_enabled) {
-	foreach (track, track_list) {
-	    if (!registerUndoAction(new UndoDeleteAction(
-		track, offset, length))) return false;
-	}
+	if (!registerUndoAction(new UndoDeleteAction(
+	    m_parent_widget, track_list, offset, length))) return false;
     }
 
     // then delete the ranges in all tracks
@@ -878,6 +830,26 @@ bool SignalManager::deleteRange(unsigned int offset, unsigned int length,
 	m_signal.deleteRange(track, offset, length);
     }
 
+    // delete all labels in the selected range
+    // and adjust the labels after the deleted range
+    foreach (Label label, labels()) {
+	const unsigned int pos = label.pos();
+	const int index        = labelIndex(label);
+
+	if (pos >= offset + length) {
+	    // move label left
+	    if (!modifyLabel(index, pos - length, label.name())) {
+		// this should never happen: position is already occupied?
+		qWarning("SignalManager::deleteRange() "\
+		         "-> killing duplicate label @ %u", pos);
+		deleteLabel(index, false);
+	    }
+	} else if ((pos >= offset) && (pos < offset + length)) {
+	    // delete the label
+	    deleteLabel(index, false);
+	}
+    }
+
     // finally set the current selection to zero-length
     selectRange(m_selection.offset(), 0);
 
@@ -934,6 +906,7 @@ void SignalManager::selectTrack(unsigned int track, bool select)
 void SignalManager::emitStatusInfo()
 {
     emit sigStatusInfo(length(), tracks(), rate(), bits());
+    emit labelsChanged(labels());
 }
 
 //***************************************************************************
@@ -949,11 +922,15 @@ void SignalManager::startUndoTransaction(const QString &name)
 
     QMutexLocker lock(&m_undo_transaction_lock);
 
+    // check for modified selection
+    checkSelectionChange();
+
     // increase recursion level
     m_undo_transaction_level++;
 
     // start/create a new transaction if none existing
     if (!m_undo_transaction) {
+
 	// if a new action starts, discard all redo actions !
 	flushRedoBuffer();
 
@@ -992,14 +969,43 @@ void SignalManager::closeUndoTransaction()
 	// not empty
 	if (m_undo_transaction) {
 	    if (!m_undo_transaction->isEmpty()) {
-		m_undo_buffer.append(m_undo_transaction);
+		// if the transaction has been aborted, undo all actions
+		// that have currently been queued but do not
+		// use the transaction any more, instead delete it.
+		if (m_undo_transaction->isAborted()) {
+		    qDebug("SignalManager::closeUndoTransaction(): aborted");
+		    while (!m_undo_transaction->isEmpty()) {
+			UndoAction *undo_action;
+			UndoAction *redo_action;
+
+			// unqueue the undo action
+			undo_action = m_undo_transaction->nextUndo();
+			m_undo_transaction->removeAll(undo_action);
+			Q_ASSERT(undo_action);
+			if (!undo_action) continue;
+
+			// execute the undo operation
+			redo_action = undo_action->undo(*this, false);
+
+			// remove the old undo action if no longer used
+			if (redo_action && (redo_action != undo_action))
+			    delete redo_action;
+			delete undo_action;
+		    }
+		    delete m_undo_transaction;
+		    m_undo_transaction = 0;
+		} else {
+		    m_undo_buffer.append(m_undo_transaction);
+		}
 	    } else {
 		qDebug("SignalManager::closeUndoTransaction(): empty");
 		delete m_undo_transaction;
+		m_undo_transaction = 0;
 	    }
 	}
 
 	// declare the current transaction as "closed"
+	rememberCurrentSelection();
 	m_undo_transaction = 0;
 	emitUndoRedoInfo();
     }
@@ -1026,13 +1032,6 @@ void SignalManager::flushUndoBuffers()
 {
     QMutexLocker lock(&m_undo_transaction_lock);
 
-    Q_ASSERT(m_undo_transaction_level == 0);
-
-    // close the current transaction
-    if (m_undo_transaction) delete m_undo_transaction;
-    m_undo_transaction = 0;
-    m_undo_transaction_level = 0;
-
     // if the signal was modified, it will stay in this state, it is
     // not possible to change to "non-modified" state through undo
     if ((!m_undo_buffer.isEmpty()) && (m_modified)) {
@@ -1051,10 +1050,8 @@ void SignalManager::flushUndoBuffers()
 //***************************************************************************
 void SignalManager::abortUndoTransaction()
 {
-    // close the current transaction
-    if (m_undo_transaction) delete m_undo_transaction;
-    m_undo_transaction = 0;
-    m_undo_transaction_level = 0;
+    // abort the current transaction
+    if (m_undo_transaction) m_undo_transaction->abort();
 }
 
 //***************************************************************************
@@ -1068,15 +1065,49 @@ void SignalManager::flushRedoBuffer()
 //***************************************************************************
 bool SignalManager::continueWithoutUndo()
 {
-    if (!m_parent_widget) return false;
+    // undo has not been enabled before?
+    if (!m_undo_transaction) return true;
+
+    // transaction has been aborted before
+    if (m_undo_transaction->isAborted()) return false;
+
+    // transaction is empty -> must have been flushed before, otherwise
+    // it would contain at least a undo action for the selection
+    // => user already has pressed "continue"
+    if (m_undo_transaction->isEmpty()) return true;
 
     if (Kwave::MessageBox::warningContinueCancel(m_parent_widget,
-	i18n("Unable to save undo information. "
-	     "Do you want to continue without undo?")) ==
-	KMessageBox::Continue)
+	"<html>"+i18n("Not enough memory for saving undo information.") +
+	"<br><br><b>"+
+	i18n("Do you want to continue without the possibility to undo?") +
+	"</b><br><br><i>" +
+	i18n("<b>Hint</b>: you can configure the amount of memory<br>"
+	     "available for undo under '%1'/'%2'.").arg(
+	     i18n("&Options").replace(QRegExp("&(.)"), "<u>\\1</u>")).arg(
+	     i18n("&Memory").replace(QRegExp("&(.)"), "<u>\\1</u>") +
+	"</i></html>")) == KMessageBox::Continue)
     {
+	// the signal was modified, it will stay in this state, it is
+	// not possible to change to "non-modified" state through undo
+	// from now on...
+	setModified(true);
+	enableModifiedChange(false);
+
+	// flush the current undo transaction
+	while (!m_undo_transaction->isEmpty()) {
+	    UndoAction *undo_action = m_undo_transaction->takeLast();
+	    if (undo_action) delete undo_action;
+	}
+
+	// flush all undo/redo buffers
+	flushUndoBuffers();
 	return true;
     }
+
+    // Set the undo transaction into "aborted" state. The final
+    // closeUndoTransaction() will take care of the rest when
+    // detecting that state and clean up...
+    abortUndoTransaction();
     return false;
 }
 
@@ -1086,32 +1117,33 @@ bool SignalManager::registerUndoAction(UndoAction *action)
     QMutexLocker lock(&m_undo_transaction_lock);
 
     Q_ASSERT(action);
-    if (!action) {
-	abortUndoTransaction();
-	return continueWithoutUndo();
-    }
+    if (!action) return continueWithoutUndo();
 
     // if undo is not enabled, this will fail -> no memory leak!
     Q_ASSERT(m_undo_enabled);
     if (!m_undo_enabled) {
 	delete action;
-	abortUndoTransaction();
 	return continueWithoutUndo();
     }
 
     // check if the undo action is too large
+    unsigned int limit_mb     = MemoryManager::instance().undoLimit();
     unsigned int needed_size  = action->undoSize();
     unsigned int needed_mb = needed_size  >> 20;
-    unsigned int limit_mb  = m_undo_limit >> 20;
     if (needed_mb > limit_mb) {
 	delete action;
-	abortUndoTransaction();
 	return continueWithoutUndo();
     }
 
     // undo has been aborted before ?
     if (!m_undo_transaction) return true;
 
+    // transaction has been aborted before
+    if (m_undo_transaction->isAborted()) {
+	delete action;
+	return true;
+    }
+
     // make room...
     freeUndoMemory(needed_size);
 
@@ -1119,7 +1151,6 @@ bool SignalManager::registerUndoAction(UndoAction *action)
     // and store all undo info
     if (!action->store(*this)) {
 	delete action;
-	abortUndoTransaction();
 	return continueWithoutUndo();
     }
 
@@ -1136,14 +1167,10 @@ bool SignalManager::saveUndoDelete(QList<unsigned int> &track_list,
     if (!m_undo_enabled) return true;
     if (track_list.isEmpty()) return true;
 
-    // loop over all tracks
-    QListIterator<unsigned int> it(track_list);
-    it.toBack();
-    while (m_undo_enabled && it.hasPrevious()) {
-	unsigned int t = it.previous();
-	UndoDeleteAction *action = new UndoDeleteAction(t, offset, length);
-	if (!registerUndoAction(action)) return false;
-    }
+    // create a undo action for deletion
+    UndoDeleteAction *action =
+	new UndoDeleteAction(m_parent_widget, track_list, offset, length);
+    if (!registerUndoAction(action)) return false;
 
     return true;
 }
@@ -1166,9 +1193,10 @@ unsigned int SignalManager::usedUndoRedoMemory()
 void SignalManager::freeUndoMemory(unsigned int needed)
 {
     unsigned int size = usedUndoRedoMemory() + needed;
+    unsigned int undo_limit = MemoryManager::instance().undoLimit() << 20;
 
     // remove old undo actions if not enough free memory
-    while (!m_undo_buffer.isEmpty() && (size > m_undo_limit)) {
+    while (!m_undo_buffer.isEmpty() && (size > undo_limit)) {
 	UndoTransaction *undo = m_undo_buffer.takeFirst();
 	if (!undo) continue;
 	unsigned int s = undo->undoSize();
@@ -1177,13 +1205,11 @@ void SignalManager::freeUndoMemory(unsigned int needed)
 
 	// if the signal was modified, it will stay in this state, it is
 	// not possible to change to "non-modified" state through undo
-	if ((!m_undo_buffer.isEmpty()) && (m_modified)) {
-	    enableModifiedChange(false);
-	}
+	if (m_modified) enableModifiedChange(false);
     }
 
     // remove old redo actions if still not enough memory
-    while (!m_redo_buffer.isEmpty() && (size > m_undo_limit)) {
+    while (!m_redo_buffer.isEmpty() && (size > undo_limit)) {
 	UndoTransaction *redo = m_redo_buffer.takeLast();
 	if (!redo) continue;
 	unsigned int s = redo->undoSize();
@@ -1227,27 +1253,24 @@ void SignalManager::undo()
 
     // get the last undo transaction and abort if none present
     if (m_undo_buffer.isEmpty()) return;
-    UndoTransaction *undo_transaction = m_undo_buffer.last();
-    Q_ASSERT(undo_transaction);
+    UndoTransaction *undo_transaction = m_undo_buffer.takeLast();
     if (!undo_transaction) return;
 
-    // remove the undo transaction from the list without deleting it
-    m_undo_buffer.takeLast();
+    // temporarily disable undo while undo itself is running
+    bool old_undo_enabled = m_undo_enabled;
+    m_undo_enabled = false;
 
     // get free memory for redo
-    // also bear in mind that the undo transaction we removed is still
-    // allocated and has to be subtracted from the undo limit. As we
-    // don't want to modify the limit, we increase the needed size.
+    unsigned int undo_limit = MemoryManager::instance().undoLimit() << 20;
     unsigned int redo_size = undo_transaction->redoSize();
     unsigned int undo_size = undo_transaction->undoSize();
-
     UndoTransaction *redo_transaction = 0;
-    if (undo_size + redo_size > m_undo_limit) {
+    if ((redo_size > undo_size) && (redo_size - undo_size > undo_limit)) {
 	// not enough memory for redo
 	qWarning("SignalManager::undo(): not enough memory for redo !");
     } else {
 	// only free the memory if it will be used
-	freeUndoMemory(undo_size + redo_size);
+	freeUndoMemory(redo_size);
 
 	// create a new redo transaction
 	QString name = undo_transaction->description();
@@ -1260,8 +1283,6 @@ void SignalManager::undo()
     if (!redo_transaction) {
 	flushRedoBuffer();
 	qDebug("SignalManager::undo(): redo buffer flushed!");
-    } else {
-	m_redo_buffer.prepend(redo_transaction);
     }
 
     // execute all undo actions and store the resulting redo
@@ -1299,20 +1320,41 @@ void SignalManager::undo()
     Q_ASSERT(undo_transaction->isEmpty());
     delete undo_transaction;
 
-    if (redo_transaction && (redo_transaction->count() <= 1)) {
-	// if there is not more than the UndoSelection action,
-	// there are no real redo actions -> no redo possible
+    if (redo_transaction && (redo_transaction->count() < 1)) {
+	// if there is no redo action -> no redo possible
 	qWarning("SignalManager::undo(): no redo possible");
-	m_redo_buffer.removeAll(redo_transaction);
 	delete redo_transaction;
+	redo_transaction = 0;
     }
 
-    if (m_undo_buffer.isEmpty() && m_modified) {
-	// try to return to non-modified mode (might be a nop if
-	// not enabled)
-	setModified(false);
+    // find out if there is still an action in the undo buffer
+    // that has to do with modification of the signal
+    if (m_modified) {
+	bool stay_modified = false;
+	foreach (UndoTransaction *transaction, m_undo_buffer) {
+	    if (!transaction) continue;
+	    if (transaction->containsModification()) {
+		stay_modified = true;
+		break;
+	    }
+	}
+	if (!stay_modified) {
+	    // try to return to non-modified mode (might be a nop if
+	    // not enabled)
+	    setModified(false);
+	}
     }
 
+    // save "redo" information if possible
+    if (redo_transaction)
+	m_redo_buffer.prepend(redo_transaction);
+
+    // remember the last selection
+    rememberCurrentSelection();
+
+    // re-enable undo
+    m_undo_enabled = old_undo_enabled;
+
     // finished / buffers have changed, emit new undo/redo info
     emitUndoRedoInfo();
 }
@@ -1322,6 +1364,9 @@ void SignalManager::redo()
 {
     QMutexLocker lock(&m_undo_transaction_lock);
 
+    // check for modified selection
+    checkSelectionChange();
+
     // get the last redo transaction and abort if none present
     if (m_redo_buffer.isEmpty()) return;
     UndoTransaction *redo_transaction = m_redo_buffer.first();
@@ -1330,20 +1375,21 @@ void SignalManager::redo()
     // remove the redo transaction from the list without deleting it
     m_redo_buffer.takeFirst();
 
+    // temporarily disable undo while redo is running
+    bool old_undo_enabled = m_undo_enabled;
+    m_undo_enabled = false;
+
     // get free memory for undo
-    // also bear in mid that the redo transaction we removed is still
-    // allocated and has to be subtracted from the undo limit. As we
-    // don't want to modify the limit, we increase the needed size.
+    unsigned int undo_limit = MemoryManager::instance().undoLimit() << 20;
     unsigned int undo_size = redo_transaction->undoSize();
     unsigned int redo_size = redo_transaction->redoSize();
-
     UndoTransaction *undo_transaction = 0;
-    if (undo_size + redo_size > m_undo_limit) {
+    if ((undo_size > redo_size) && (undo_size - redo_size > undo_limit)) {
 	// not enough memory for undo
 	qWarning("SignalManager::redo(): not enough memory for undo !");
     } else {
 	// only free the memory if it will be used
-	freeUndoMemory(undo_size + redo_size);
+	freeUndoMemory(undo_size);
 
 	// create a new undo transaction
 	QString name = redo_transaction->description();
@@ -1356,7 +1402,6 @@ void SignalManager::redo()
     if (!undo_transaction) {
 	qDeleteAll(m_undo_buffer);
 	m_undo_buffer.clear();
-	qDebug("SignalManager::redo(): undo buffer flushed!");
     } else {
 	m_undo_buffer.append(undo_transaction);
     }
@@ -1396,14 +1441,19 @@ void SignalManager::redo()
     Q_ASSERT(redo_transaction->isEmpty());
     delete redo_transaction;
 
-    if (undo_transaction && (undo_transaction->count() <= 1)) {
-	// if there is not more than the UndoSelection action,
-	// there are no real undo actions -> no undo possible
+    if (undo_transaction && (undo_transaction->count() < 1)) {
+	// if there is no undo action -> no undo possible
 	qWarning("SignalManager::redo(): no undo possible");
 	m_undo_buffer.removeAll(undo_transaction);
 	delete undo_transaction;
     }
 
+    // remember the last selection
+    rememberCurrentSelection();
+
+    // re-enable undo
+    m_undo_enabled = old_undo_enabled;
+
     // finished / buffers have changed, emit new undo/redo info
     emitUndoRedoInfo();
 }
@@ -1442,20 +1492,23 @@ void SignalManager::setFileInfo(FileInfo &new_info, bool with_undo)
 }
 
 //***************************************************************************
-Label *SignalManager::findLabel(unsigned int pos) const
+Label SignalManager::findLabel(unsigned int pos)
 {
-    foreach (Label *label, labels()) {
-	if (label && (label->pos() == pos)) return label; // found it
+    QMutableListIterator<Label> it(labels());
+    while (it.hasNext())
+    {
+	Label &label = it.next();
+	if (label.pos() == pos) return label; // found it
     }
 
-    return 0; // nothing found
+    return Label(); // nothing found
 }
 
 //***************************************************************************
-int SignalManager::labelIndex(const Label *label) const
+int SignalManager::labelIndex(const Label &label) const
 {
     int index = 0;
-    foreach (Label *l, labels()) {
+    foreach (const Label &l, labels()) {
 	if (l == label) return index; // found it
 	index++;
     }
@@ -1463,8 +1516,9 @@ int SignalManager::labelIndex(const Label *label) const
 }
 
 //***************************************************************************
-Label *SignalManager::labelAtIndex(int index)
+Label SignalManager::labelAtIndex(int index)
 {
+    if ((index < 0) || (index >= labels().size())) return Label();
     return labels().at(index);
 }
 
@@ -1472,44 +1526,41 @@ Label *SignalManager::labelAtIndex(int index)
 bool SignalManager::addLabel(unsigned int pos)
 {
     // if there already is a label at the given position, do nothing
-    if (findLabel(pos)) return false;
+    if (!findLabel(pos).isNull()) return false;
 
     // create a new label
-    Label *label = new Label(pos, "");
-    Q_ASSERT(label);
-    if (!label) return false;
+    Label label(pos, "");
 
     // put the label into the list
     labels().append(label);
     labels().sort();
-    emit sigLabelCountChanged();
 
     // register the undo action
     UndoTransactionGuard undo(*this, i18n("add label"));
     if (!registerUndoAction(new UndoAddLabelAction(labelIndex(label)))) {
 	labels().removeAll(label);
-	delete label;
-	emit sigLabelCountChanged();
 	return false;
     }
+
+    emit sigLabelCountChanged();
+    emit labelsChanged(labels());
     return true;
 }
 
 //***************************************************************************
-Label *SignalManager::addLabel(unsigned int pos, const QString &name)
+Label SignalManager::addLabel(unsigned int pos, const QString &name)
 {
     // if there already is a label at the given position, do nothing
-    if (findLabel(pos)) return 0;
+    if (!findLabel(pos).isNull()) return Label();
 
     // create a new label
-    Label *label = new Label(pos, name);
-    Q_ASSERT(label);
-    if (!label) return 0;
+    Label label(pos, name);
 
     // put the label into the list
     labels().append(label);
     labels().sort();
     emit sigLabelCountChanged();
+    emit labelsChanged(labels());
 
     return label;
 }
@@ -1518,22 +1569,87 @@ Label *SignalManager::addLabel(unsigned int pos, const QString &name)
 void SignalManager::deleteLabel(int index, bool with_undo)
 {
     Q_ASSERT(index >= 0);
-    Q_ASSERT(index < (int)labels().count());
-    if ((index < 0) || (index >= (int)labels().count())) return;
+    Q_ASSERT(index < static_cast<int>(labels().count()));
+    if ((index < 0) || (index >= static_cast<int>(labels().count()))) return;
 
-    Label *label = labels().at(index);
-    Q_ASSERT(label);
-    if (!label) return;
+    Label label = labels().at(index);
 
     // register the undo action
     if (with_undo) {
 	UndoTransactionGuard undo(*this, i18n("delete label"));
-	if (!registerUndoAction(new UndoDeleteLabelAction(*label)))
+	if (!registerUndoAction(new UndoDeleteLabelAction(label)))
 	    return;
     }
 
     labels().removeAll(label);
     emit sigLabelCountChanged();
+    emit labelsChanged(labels());
+}
+
+//***************************************************************************
+bool SignalManager::modifyLabel(int index, unsigned int pos,
+                                const QString &name)
+{
+    Q_ASSERT(index >= 0);
+    Q_ASSERT(index < static_cast<int>(labels().count()));
+    if ((index < 0) || (index >= static_cast<int>(labels().count())))
+	return false;
+
+    LabelList &list = labels();
+    Label &label = list[index];
+
+    // check: if the label should be moved and there already is a label
+    // at the new position -> fail
+    if ((pos != label.pos()) && !findLabel(pos).isNull())
+	return false;
+
+    label.moveTo(pos);
+    label.rename(name);
+    labels().sort();
+
+    emit labelsChanged(labels());
+    return true;
+}
+
+//***************************************************************************
+void SignalManager::rememberCurrentSelection()
+{
+    m_last_selection       = m_selection;
+    m_last_track_selection = selectedTracks();
+}
+
+//***************************************************************************
+void SignalManager::checkSelectionChange()
+{
+    if (m_undo_transaction_level) return;
+
+    // detect sample selection change
+    bool range_modified = !(m_selection == m_last_selection);
+
+    // detect track selection change
+    QList<unsigned int> tracks = selectedTracks();
+    bool tracks_modified = !(tracks == m_last_track_selection);
+
+    if (range_modified || tracks_modified) {
+	// selection has changed since last undo/redo operation
+// 	qDebug("SignalManager::checkSelectionChange() => manually modified");
+
+	// temporarily activate the previous selection (last stored)
+	Selection new_selection(m_selection);
+	m_selection = m_last_selection;
+	selectTracks(m_last_track_selection);
+
+	// save the last selection into a undo action
+	if (tracks_modified && !range_modified)
+	    UndoTransactionGuard undo(*this, i18n("manual track selection"));
+	else
+	    UndoTransactionGuard undo(*this, i18n("manual selection"));
+
+	// restore the current selection again
+	m_selection = new_selection;
+	selectTracks(tracks);
+    }
+
 }
 
 //***************************************************************************
