@@ -88,13 +88,13 @@ public:
     void close();
 
     /** Returns true if the signal is closed */
-    inline bool isClosed() { return m_closed; };
+    inline bool isClosed() { return m_closed; }
 
     /** Returns true if the signal is empty. */
-    inline bool isEmpty() { return m_empty; };
+    inline bool isEmpty() { return m_empty; }
 
     /** Returns true if the signal is modified */
-    inline bool isModified() { return m_modified; };
+    inline bool isModified() { return m_modified; }
 
     /** Returns a reference to the playback controller. */
     PlaybackController &playbackController();
@@ -106,13 +106,13 @@ public:
      * Returns a reference to the FileInfo object associated with the
      * currently opened file.
      */
-    FileInfo &fileInfo() { return m_file_info; };
+    FileInfo &fileInfo() { return m_file_info; }
 
     /**
      * Returns a reference to the FileInfo object associated with the
      * currently opened file (same as above but 'const').
      */
-    const FileInfo &fileInfo() const { return m_file_info; };
+    const FileInfo &fileInfo() const { return m_file_info; }
 
     /**
      * Returns a reference to the current name of the signal. If no signal is
@@ -123,22 +123,22 @@ public:
     /**
      * Returns the current sample resolution in bits per sample
      */
-    inline unsigned int bits() const { return m_file_info.bits(); };
+    inline unsigned int bits() const { return m_file_info.bits(); }
 
     /** Returns the current sample rate in samples per second */
-    inline double rate() const { return m_file_info.rate(); };
+    inline double rate() const { return m_file_info.rate(); }
 
     /** Returns the current number of tracks */
-    inline unsigned int tracks() { return m_signal.tracks(); };
+    inline unsigned int tracks() { return m_signal.tracks(); }
 
     /**
      * Returns the number of samples in the current signal. Will be
      * zero if no signal is loaded.
      */
-    inline unsigned int length() { return m_signal.length(); };
+    inline unsigned int length() { return m_signal.length(); }
 
     /** Returns a reference to the current selection */
-    inline Selection &selection() { return m_selection; };
+    inline Selection &selection() { return m_selection; }
 
     /**
      * Returns true if a given track is selected. If the track does
@@ -146,8 +146,7 @@ public:
      */
     inline bool trackSelected(unsigned int track) {
 	return (m_signal.trackSelected(track));
-    };
-
+    }
 
     /**
      * Returns an array of indices of currently selected tracks.
@@ -258,20 +257,20 @@ public:
 	unsigned int left = 0, unsigned int right = UINT_MAX)
     {
 	return m_signal.openSampleReader(track, left, right);
-    };
+    }
 
     /** Returns true if undo/redo is currently enabled */
-    inline bool undoEnabled() { return m_undo_enabled; };
+    inline bool undoEnabled() { return m_undo_enabled; }
 
     /** Return true if undo is possible */
     inline bool canUndo() {
 	return !m_undo_buffer.isEmpty() && undoEnabled();
-    };
+    }
 
     /** Return true if redo is possible */
     inline bool canRedo() {
 	return !m_redo_buffer.isEmpty() && undoEnabled();
-    };
+    }
 
     /**
      * Enables undo and redo. If undo/redo is already enabled, nothing
@@ -287,14 +286,6 @@ public:
      */
     void disableUndo();
 
-    /**
-     * Deletes the current selection and inserts the content of the
-     * clipboard at the position of the first selected sample.
-     * If the clipboard contains more or less tracks than the selection,
-     * the signal will be mixed over all tracks.
-     */
-    void paste(ClipBoard &clipboard, unsigned int offset, unsigned int length);
-
     /**
      * Sets a complete set of file infos, including undo information
      */
@@ -313,7 +304,7 @@ public:
      * @param name the name of the label
      * @return pointer to the new created label
      */
-    Label *addLabel(unsigned int pos, const QString &name);
+    Label addLabel(unsigned int pos, const QString &name);
 
     /**
      * delete an existing label
@@ -322,26 +313,40 @@ public:
      */
     void deleteLabel(int index, bool with_undo);
 
+    /**
+     * modify an existing label at a given index
+     * (always without undo)
+     * @param index the index of the label [0...N-1]
+     * @param pos position of the label [samples]
+     * @param name the name of the label
+     * @return true if succeeded, false if the index is out of range or if
+     *         the new position is already occupied by an existing label
+     */
+    bool modifyLabel(int index, unsigned int pos, const QString &name);
+
     /**
      * find a label by it's index
      * @param index the index of the label [0...N-1]
-     * @return pointer to the label or null pointer if not found
+     * @return a valid label or a "null" label if not found
      */
-    Label *labelAtIndex(int index);
+    Label labelAtIndex(int index);
 
     /**
      * Returns the index of a label, counting from zero
-     * @param label pointer to a Label
-     * @return index [0...N-1] or -1 if label is a null pointer
+     * @param label reference to a Label
+     * @return index [0...N-1] or -1 if label is a null pointer or not found
      */
-    int labelIndex(const Label *label) const;
+    int labelIndex(const Label &label) const;
 
     /**
      * returns the label at a given exact position
      * @param pos position of the label [samples]
-     * @return the label at the position or null if not found
+     * @return valid label at the position or null label if not found
      */
-    Label *findLabel(unsigned int pos) const;
+    Label findLabel(unsigned int pos);
+
+    /** Shortcut for accessing the label list @note can be modified */
+    inline LabelList &labels() { return m_file_info.labels(); }
 
 signals:
 
@@ -430,6 +435,9 @@ signals:
     /** Emitted whenever the numer of labels has changed */
     void sigLabelCountChanged();
 
+    /** Emitted whenever a label has been added, deleted or modified */
+    void labelsChanged(const LabelList &labels);
+
 public slots:
 
     /**
@@ -526,7 +534,7 @@ protected:
                             unsigned int length)
     {
 	m_signal.deleteRange(track, offset, length);
-    };
+    }
 
 protected:
 
@@ -621,11 +629,18 @@ private:
      */
     void enableModifiedChange(bool en);
 
-    /** Shortcut for accessing the label list @note can be modified */
-    inline LabelList &labels() { return m_file_info.labels(); };
-
     /** Shortcut for accessing the label list @note cannot be modified */
-    inline const LabelList &labels() const { return m_file_info.labels(); };
+    inline const LabelList &labels() const { return m_file_info.labels(); }
+
+    /** saves the current sample and track selection */
+    void rememberCurrentSelection();
+
+    /**
+     * Check whether the selection has changed since the start of
+     * the last undo and create a new undo action if the selection
+     * has been modified (e.g. manually)
+     */
+    void checkSelectionChange();
 
 private:
 
@@ -655,6 +670,12 @@ private:
     /** the current selection */
     Selection m_selection;
 
+    /** the last selection (stored in undo) */
+    Selection m_last_selection;
+
+    /** the last track selection (stored in undo) */
+    QList <unsigned int> m_last_track_selection;
+
     /**
      * Last known length of the signal. This will be used if a track is
      * added to an empty signal and prevents from the creation of a
@@ -683,9 +704,6 @@ private:
     /** mutex for locking undo transactions */
     QMutex m_undo_transaction_lock;
 
-    /** maximum memory for undo */
-    unsigned int m_undo_limit;
-
     /** info about the file, @see class FileInfo */
     FileInfo m_file_info;
 };
