@@ -19,13 +19,7 @@
 #include <stdlib.h>
 
 extern "C" {
-#ifdef USE_BUILTIN_LIBAUDIOFILE
-#include "libaudiofile/audiofile.h" // from Kwave's copy of libaudiofile
-#include "libaudiofile/af_vfs.h"    // from Kwave's copy of libaudiofile
-#else /* USE_BUILTIN_LIBAUDIOFILE */
-#include <audiofile.h> // from system
-#include <af_vfs.h>    // from system
-#endif /* USE_BUILTIN_LIBAUDIOFILE */
+#include <audiofile.h>
 }
 
 #include <QList>
@@ -36,6 +30,7 @@ extern "C" {
 #include <kmimetype.h>
 
 #include "libkwave/byteswap.h"
+#include "libkwave/ConfirmCancelProxy.h"
 #include "libkwave/MultiTrackWriter.h"
 #include "libkwave/Label.h"
 #include "libkwave/MessageBox.h"
@@ -44,8 +39,6 @@ extern "C" {
 #include "libkwave/Signal.h"
 #include "libkwave/VirtualAudioFile.h"
 
-#include "libgui/ConfirmCancelProxy.h"
-
 #include "RecoveryBuffer.h"
 #include "RecoveryMapping.h"
 #include "RecoverySource.h"
@@ -159,8 +152,8 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     progress.reset();
     if (progress.wasCanceled()) return false;
 
-    qDebug("--- RIFF file structure after first pass ---");
-    parser.dumpStructure();
+//     qDebug("--- RIFF file structure after first pass ---");
+//     parser.dumpStructure();
 
     // check if there is a RIFF chunk at all...
     RIFFChunk *riff_chunk = parser.findChunk("/RIFF:WAVE");
@@ -221,17 +214,17 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 
     u_int32_t fmt_offset = 0;
     if (fmt_chunk) fmt_offset = fmt_chunk->dataStart();
-    qDebug("fmt chunk starts at 0x%08X", fmt_offset);
+//     qDebug("fmt chunk starts at 0x%08X", fmt_offset);
 
     u_int32_t data_offset = 0;
     u_int32_t data_size = 0;
     if (data_chunk) {
 	data_offset = data_chunk->dataStart();
 	data_size   = data_chunk->physLength();
-	qDebug("data chunk at 0x%08X (%u byte)", data_offset, data_size);
+// 	qDebug("data chunk at 0x%08X (%u byte)", data_offset, data_size);
     }
 
-    if (data_size <= 4) {
+    if (!data_size) {
 	Kwave::MessageBox::sorry(widget,
 	    i18n("The opened file is no .WAV file or damaged:\n"
 	    "There is not enough valid sound data.\n\n"
@@ -274,10 +267,11 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     src.seek(fmt_offset);
 
     // get the encoded block of data from the mime source
-    CHECK((int)src.size() > (int)sizeof(wav_header_t)+8);
+    CHECK(static_cast<unsigned int>(src.size()) >
+          sizeof(wav_header_t) + 8);
 
     // get the header
-    src.read((char *)&header, sizeof(wav_fmt_header_t));
+    src.read(reinterpret_cast<char *>(&header), sizeof(wav_fmt_header_t));
 #if Q_BYTE_ORDER == Q_BIG_ENDIAN
     header.min.format      = bswap_16(header.min.format);
     header.min.channels    = bswap_16(header.min.channels);
@@ -293,16 +287,16 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     WavFormatMap known_formats;
     QString format_name = known_formats.findName(header.min.format);
 
-    qDebug("-------------------------");
-    qDebug("wav header:");
-    qDebug("mode        = 0x%04X, (%s)", header.min.format,
-                                         format_name.toLocal8Bit().data());
-    qDebug("channels    = %d", header.min.channels);
-    qDebug("rate        = %u", header.min.samplerate);
-    qDebug("bytes/s     = %u", header.min.bytespersec);
-    qDebug("block align = %d", header.min.blockalign);
-    qDebug("bits/sample = %d", header.min.bitwidth);
-    qDebug("-------------------------");
+//     qDebug("-------------------------");
+//     qDebug("wav header:");
+//     qDebug("mode        = 0x%04X, (%s)", header.min.format,
+//                                          format_name.toLocal8Bit().data());
+//     qDebug("channels    = %d", header.min.channels);
+//     qDebug("rate        = %u", header.min.samplerate);
+//     qDebug("bytes/s     = %u", header.min.bytespersec);
+//     qDebug("block align = %d", header.min.blockalign);
+//     qDebug("bits/sample = %d", header.min.bitwidth);
+//     qDebug("-------------------------");
 
     // open the file through libaudiofile :)
     if (need_repair) {
@@ -311,7 +305,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 	if (!repair_list) return false;
 
 	RIFFChunk *root = (riff_chunk) ? riff_chunk : parser.findChunk("");
-	parser.dumpStructure();
+// 	parser.dumpStructure();
 //	qDebug("riff chunk = %p, parser.findChunk('')=%p", riff_chunk,
 //	    parser.findChunk(""));
 	repair(repair_list, root, fmt_chunk, data_chunk);
@@ -369,7 +363,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 
     int sample_format;
     afGetVirtualSampleFormat(fh, AF_DEFAULT_TRACK, &sample_format,
-	(int *)(&bits));
+	reinterpret_cast<int *>(&bits));
 
     int compression = afGetCompression(fh, AF_DEFAULT_TRACK);
     if (static_cast<signed int>(bits) < 0) bits = 0;
@@ -408,14 +402,14 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
     RIFFChunk *cue_chunk = parser.findChunk("/RIFF:WAVE/cue ");
     if (cue_chunk) {
 	// found a cue list chunk !
-	unsigned int length = cue_chunk->dataLength();
 	u_int32_t count;
 
 	src.seek(cue_chunk->dataStart());
-	src.read((char *)&count, 4);
+	src.read(reinterpret_cast<char *>(&count), 4);
 	count = LE32_TO_CPU(count);
-	qDebug("cue list found: %u entries, %u bytes (should be: %u)",
-	    count, length, count * (6 * 4) + 4);
+// 	unsigned int length = cue_chunk->dataLength();
+// 	qDebug("cue list found: %u entries, %u bytes (should be: %u)",
+// 	    count, length, count * (6 * 4) + 4);
 
 	for (unsigned int i = 0; i < count; i++) {
 	    u_int32_t data, index, position;
@@ -430,31 +424,40 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 	     *     u_int32_t dwSampleOffset; <- label.pos()
 	     * } cue_list_entry_t;
 	     */
-	    src.read((char *)&data, 4); /* dwIdentifier */
+
+	    /* dwIdentifier */
+	    src.read(reinterpret_cast<char *>(&data), 4);
 	    index = LE32_TO_CPU(data);
-	    src.read((char *)&data, 4); /* dwPosition (ignored) */
-	    src.read((char *)&data, 4); /* fccChunk */
+
+	    /* dwPosition (ignored) */
+	    src.read(reinterpret_cast<char *>(&data), 4);
+
+	    /* fccChunk */
+	    src.read(reinterpret_cast<char *>(&data), 4);
 	    /* we currently support only 'data' */
-	    if (qstrncmp((const char *)&data, "data", 4) != 0) {
+	    if (qstrncmp(reinterpret_cast<const char *>(&data), "data", 4)) {
 		qWarning("cue list entry %d refers to '%s', "\
                          "which is not supported -> skipped",
-		         index, QByteArray((const char *)&data, 4).data());
+		         index, QByteArray(
+		         reinterpret_cast<const char *>(&data), 4).data());
 		continue;
 	    }
-	    src.read((char *)&data, 4); /* dwChunkStart (must be 0) */
+	    src.read(reinterpret_cast<char *>(&data), 4);
+	    /* dwChunkStart (must be 0) */
 	    if (data != 0) {
 		qWarning("cue list entry %d has dwChunkStart != 0 -> skipped",
 		         index);
 		continue;
 	    }
-	    src.read((char *)&data, 4); /* dwBlockStart (must be 0) */
+	    src.read(reinterpret_cast<char *>(&data), 4);
+	    /* dwBlockStart (must be 0) */
 	    if (data != 0) {
 		qWarning("cue list entry %d has dwBlockStart != 0 -> skipped",
 		         index);
 		continue;
 	    }
 
-	    src.read((char *)&data, 4); /* dwSampleOffset */
+	    src.read(reinterpret_cast<char *>(&data), 4); /* dwSampleOffset */
 	    position = LE32_TO_CPU(data);
 
 	    // as we now have index and position, find out the name
@@ -479,7 +482,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 
 		    data = 0;
 		    src.seek(labl_chunk->dataStart());
-		    src.read((char *)&data, 4); /* dwIdentifier */
+		    src.read(reinterpret_cast<char *>(&data), 4); /* dwIdentifier */
 		    labl_index = LE32_TO_CPU(data);
 		    if (labl_index == index) {
 			found = true;
@@ -493,7 +496,7 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 			length -= 4;
 			name.resize(length);
 			src.seek(labl_chunk->dataStart() + 4);
-			src.read((char *)name.data(), length);
+			src.read(static_cast<char *>(name.data()), length);
 			if (name[name.count()-1] != '\0')
 			    name += '\0';
 		    }
@@ -501,15 +504,13 @@ bool WavDecoder::open(QWidget *widget, QIODevice &src)
 	    }
 
 	    if (!name.length()) {
-		qDebug("cue list entry %d has no name", index);
+// 		qDebug("cue list entry %d has no name", index);
 		name = "";
 	    }
 
 	    // put a new label into the list
 	    QString str = QString::fromUtf8(name);
-	    Label *label = new Label(position, str);
-	    Q_ASSERT(label);
-	    if (label) info().labels().append(label);
+	    info().labels().append(Label(position, str));
 	}
     }
     info().labels().sort();
@@ -538,14 +539,23 @@ bool WavDecoder::decode(QWidget */*widget*/, MultiTrackWriter &dst)
     Q_ASSERT(fh);
     if (!fh) return false;
 
-    info().dump(); // ###
+//     info().dump();
 
-    unsigned int frame_size = (unsigned int)afGetVirtualFrameSize(fh,
-	AF_DEFAULT_TRACK, 1);
+    // allocate an array of SampleWriters, for speeding up
+    QVector<SampleWriter *>writers;
+    for (unsigned int t = 0; t < dst.tracks(); t++)
+	writers.append(dst[t]);
+    Q_ASSERT(writers.count() == static_cast<int>(dst.tracks()));
+    if (writers.count() != static_cast<int>(dst.tracks())) return false;
+    SampleWriter **writer_fast = writers.data();
+
+    unsigned int frame_size = static_cast<unsigned int>(
+	afGetVirtualFrameSize(fh, AF_DEFAULT_TRACK, 1));
 
     // allocate a buffer for input data
     const unsigned int buffer_frames = (8*1024);
-    int32_t *buffer = (int32_t *)malloc(buffer_frames * frame_size);
+    int32_t *buffer = static_cast<int32_t *>(
+	malloc(buffer_frames * frame_size));
     Q_ASSERT(buffer);
     if (!buffer) return false;
 
@@ -556,7 +566,7 @@ bool WavDecoder::decode(QWidget */*widget*/, MultiTrackWriter &dst)
 	unsigned int frames = buffer_frames;
 	if (frames > rest) frames = rest;
 	unsigned int buffer_used = afReadFrames(fh,
-	    AF_DEFAULT_TRACK, (char *)buffer, frames);
+	    AF_DEFAULT_TRACK, reinterpret_cast<char *>(buffer), frames);
 
 	// break if eof reached
 	Q_ASSERT(buffer_used);
@@ -577,7 +587,7 @@ bool WavDecoder::decode(QWidget */*widget*/, MultiTrackWriter &dst)
 
 		// the following cast is only necessary if
 		// sample_t is not equal to a u_int32_t
-		*(dst[track]) << static_cast<sample_t>(s);
+		*(writer_fast[track]) << static_cast<sample_t>(s);
 	    }
 	}
 
