@@ -34,7 +34,7 @@ KWAVE_PLUGIN(NoisePlugin,"noise","Thomas Eschenbacher");
 
 //***************************************************************************
 NoisePlugin::NoisePlugin(const PluginContext &context)
-    :KwavePlugin(context), m_stop(false)
+    :Kwave::Plugin(context)
 {
 }
 
@@ -45,7 +45,6 @@ void NoisePlugin::run(QStringList)
 
     UndoTransactionGuard undo_guard(*this, i18n("noise"));
 
-    m_stop = false;
     selection(&first, &last, true);
 
     // create all objects
@@ -54,9 +53,17 @@ void NoisePlugin::run(QStringList)
     MultiTrackWriter sink(signalManager(), selectedTracks(), Overwrite,
         first, last);
 
+    // break if aborted
+    if (!sink.tracks()) return;
+
+    // connect the progress dialog
+    connect(&sink, SIGNAL(progress(unsigned int)),
+	    this,  SLOT(updateProgress(unsigned int)),
+	    Qt::QueuedConnection);
+
     // connect them
-    if (!Kwave::connect(source, SIGNAL(output(Kwave::SampleArray &)),
-                        sink,   SLOT(input(Kwave::SampleArray &))))
+    if (!Kwave::connect(source, SIGNAL(output(Kwave::SampleArray)),
+                        sink,   SLOT(input(Kwave::SampleArray))))
     {
 	close();
 	return;
@@ -64,7 +71,7 @@ void NoisePlugin::run(QStringList)
 
     // transport the samples
     qDebug("NoisePlugin: filter started [%u ... %u] ...", first, last);
-    while (!m_stop && !(sink.done())) {
+    while (!shouldStop() && !sink.done()) {
 	source.goOn();
     }
     qDebug("NoisePlugin: filter done.");
@@ -72,13 +79,6 @@ void NoisePlugin::run(QStringList)
     close();
 }
 
-//***************************************************************************
-int NoisePlugin::stop()
-{
-    m_stop = true;
-    return KwavePlugin::stop();
-}
-
 //***************************************************************************
 #include "NoisePlugin.moc"
 //***************************************************************************
