@@ -67,13 +67,18 @@ KWAVE_PLUGIN(PlayBackPlugin,"playback","Thomas Eschenbacher");
 
 //***************************************************************************
 PlayBackPlugin::PlayBackPlugin(const PluginContext &context)
-    :KwavePlugin(context), m_dialog(0),
+    :Kwave::Plugin(context), m_dialog(0),
     m_device(0), m_lock_device(), m_playback_params(),
     m_playback_controller(manager().playbackController()),
-    m_stop(false),
     m_old_first(0),
     m_old_last(0)
 {
+#ifdef HAVE_ALSA_SUPPORT
+    // set builtin defaults to ALSA
+    m_playback_params.method = PLAYBACK_ALSA;
+    m_playback_params.device = "default";
+#endif /* HAVE_ALSA_SUPPORT */
+
     connect(this, SIGNAL(sigPlaybackDone()),
             &m_playback_controller, SLOT(playbackDone()));
     connect(this, SIGNAL(sigPlaybackPos(unsigned int)),
@@ -96,7 +101,6 @@ PlayBackPlugin::~PlayBackPlugin()
 
     // close the device now if it accidentally is still open
     QMutexLocker lock_for_delete(&m_lock_device);
-    m_stop = true;
     if (m_device) delete m_device;
     m_device = 0;
 }
@@ -116,7 +120,7 @@ int PlayBackPlugin::interpreteParameters(QStringList &params)
     Q_ASSERT(ok);
     if (!ok) return -EINVAL;
     if (method >= PLAYBACK_INVALID) method = PLAYBACK_NONE;
-    m_playback_params.method = (playback_method_t)method;
+    m_playback_params.method = static_cast<playback_method_t>(method);
 
     // parameter #1: playback device [/dev/dsp , ... ]
     param = params[1];
@@ -199,7 +203,7 @@ QStringList *PlayBackPlugin::setup(QStringList &previous_params)
 
 	    // parameter #0: playback method
 	    param = param.setNum(
-	        (unsigned int)m_playback_params.method);
+	        static_cast<unsigned int>(m_playback_params.method));
 	    result->append(param);
 
 	    // parameter #1: playback device [/dev/dsp , ... ]
@@ -256,7 +260,8 @@ PlayBackDevice *PlayBackPlugin::createDevice(playback_method_t &method)
 #endif /* HAVE_ALSA_SUPPORT */
 
 	    default:
-		qDebug("unsupported playback method (%d)", (int)method);
+		qDebug("unsupported playback method (%d)",
+		    static_cast<int>(method));
 		if (!searching) {
 		    // start trying out all other methods
 		    searching = true;
@@ -268,7 +273,7 @@ PlayBackDevice *PlayBackPlugin::createDevice(playback_method_t &method)
 		    ++method;
 		}
 		qDebug("unsupported playback method - trying next (%d)",
-		    (int)method);
+		    static_cast<int>(method));
 		if (method != PLAYBACK_INVALID) continue;
 	}
 	break;
@@ -280,7 +285,7 @@ PlayBackDevice *PlayBackPlugin::createDevice(playback_method_t &method)
 //***************************************************************************
 void PlayBackPlugin::setMethod(playback_method_t method)
 {
-    qDebug("PlayBackPlugin::setMethod(%d)", (int)method);
+    qDebug("PlayBackPlugin::setMethod(%d)", static_cast<int>(method));
     QString last_device_name = m_playback_params.device;
 
     // set hourglass cursor
@@ -302,10 +307,10 @@ void PlayBackPlugin::setMethod(playback_method_t method)
 
 	    // save the current device
 	    cfg.writeEntry(QString("last_device_%1").arg(
-		(int)m_playback_params.method),
+		static_cast<int>(m_playback_params.method)),
 		m_dialog->params().device);
 	    qDebug(">>> %d -> '%s'",
-	           (int)m_playback_params.method,
+	           static_cast<int>(m_playback_params.method),
 	           m_dialog->params().device.toLocal8Bit().data());
 	    cfg.sync();
 	}
@@ -315,8 +320,10 @@ void PlayBackPlugin::setMethod(playback_method_t method)
 
 	if (m_dialog) {
 	    // restore the previous one
-	    device = cfg.readEntry(QString("last_device_%1").arg((int)method));
-	    qDebug("<<< %d -> '%s'", (int)method, device.toLocal8Bit().data());
+	    device = cfg.readEntry(QString("last_device_%1").arg(
+		static_cast<int>(method)));
+	    qDebug("<<< %d -> '%s'", static_cast<int>(method),
+		device.toLocal8Bit().data());
 	    last_device_name = device;
 	    m_playback_params.device = device;
 	    m_dialog->setDevice(m_playback_params.device);
@@ -358,19 +365,32 @@ void PlayBackPlugin::setMethod(playback_method_t method)
 //***************************************************************************
 void PlayBackPlugin::setDevice(const QString &device)
 {
-//     qDebug("PlayBackPlugin::setDevice(%s)", device.local8Bit().data());
+//     qDebug("PlayBackPlugin::setDevice(%s)", device.toLocal8Bit().data());
+
+    // select the default device if new one is not supported
+    QString dev = device;
+    if (m_device) {
+	QStringList supported = m_device->supportedDevices();
+	if (!supported.isEmpty() && !supported.contains(device)) {
+	    // use the first entry as default
+	    dev = supported.first();
+	    qDebug("PlayBackPlugin::setDevice(%s) -> fallback to '%s'",
+		device.toLocal8Bit().data(),
+		dev.toLocal8Bit().data());
+	}
+    }
 
     // set the device in the dialog
-    if (m_dialog) m_dialog->setDevice(device);
-    m_playback_params.device = device;
+    if (m_dialog) m_dialog->setDevice(dev);
+    m_playback_params.device = dev;
 
     QList<unsigned int> supported_bits;
-    if (m_device) supported_bits = m_device->supportedBits(device);
+    if (m_device) supported_bits = m_device->supportedBits(dev);
     if (m_dialog) m_dialog->setSupportedBits(supported_bits);
 
     unsigned int min = 0;
     unsigned int max = 0;
-    if (m_device) m_device->detectChannels(device, min, max);
+    if (m_device) m_device->detectChannels(dev, min, max);
     if (m_dialog) m_dialog->setSupportedChannels(min, max);
 }
 
@@ -517,7 +537,6 @@ void PlayBackPlugin::startDevicePlayBack()
 
     m_old_first = first;
     m_old_last = last;
-    m_stop = false;
 
     QStringList empty_list;
     use();
@@ -527,7 +546,7 @@ void PlayBackPlugin::startDevicePlayBack()
 //***************************************************************************
 void PlayBackPlugin::stopDevicePlayBack()
 {
-    m_stop = true;
+    cancel();
     if (!isRunning()) {
 	qDebug("PlayBackPlugin::stopDevicePlayBack() - not running");
 	emit sigPlaybackDone();
@@ -575,8 +594,8 @@ void PlayBackPlugin::run(QStringList)
 	    unsigned int l = (n1 > m1) ? n1 : m1;
 	    unsigned int r = (n2 < m2) ? n2 : m2;
 
-	    matrix[x][y] = (r > l) ?
-		(double)(r-l) / (double)audible_count : 0.0;
+	    matrix[x][y] = (r > l) ? static_cast<double>(r-l) /
+		static_cast<double>(audible_count) : 0.0;
 	}
     }
 
@@ -601,7 +620,7 @@ void PlayBackPlugin::run(QStringList)
 	    }
 	}
 
-	while ((pos++ <= last) && !m_stop) {
+	while ((pos++ <= last) && !shouldStop()) {
 	    unsigned int x;
 	    for (x=0; x < audible_count; x++) {
 		in_samples[x] = 0;
@@ -619,22 +638,22 @@ void PlayBackPlugin::run(QStringList)
 	    for (y=0; y < out_channels; y++) {
 		double sum = 0;
 		for (x=0; x < audible_count; x++) {
-		    sum += (double)in_samples[x] * matrix[x][y];
+		    sum += static_cast<double>(in_samples[x]) * matrix[x][y];
 		}
-		out_samples[y] = (sample_t)sum;
+		out_samples[y] = static_cast<sample_t>(sum);
 	    }
 
 	    // write samples to the playback device
 	    int result = m_device->write(out_samples);
 	    if (result) {
-		m_stop = true;
+		cancel();
 		pos = last;
 	    }
 
 	    // update the playback position if timer elapsed
 	    if (!pos_countdown) {
-		pos_countdown = (unsigned int)ceil(m_playback_params.rate /
-			SCREEN_REFRESHES_PER_SECOND);
+		pos_countdown = static_cast<unsigned int>(ceil(
+		    m_playback_params.rate / SCREEN_REFRESHES_PER_SECOND));
 		emit sigPlaybackPos(pos);
 	    } else {
 		--pos_countdown;
@@ -643,12 +662,12 @@ void PlayBackPlugin::run(QStringList)
 
 	// maybe we loop. in this case the playback starts
 	// again from the left marker
-	if (m_playback_controller.loop() && !m_stop) {
+	if (m_playback_controller.loop() && !shouldStop()) {
 	    input.reset();
 	    pos = m_playback_controller.startPos();
 	}
 
-    } while (m_playback_controller.loop() && !m_stop);
+    } while (m_playback_controller.loop() && !shouldStop());
 
     // we are done, so close the output device
     m_device->close();
@@ -694,7 +713,7 @@ void PlayBackPlugin::testPlayBack()
     if (!sink) return;
 
     float t_period = t_sweep * tracks;
-    unsigned int curve_length = (unsigned int)(t_period * rate);
+    unsigned int curve_length = static_cast<unsigned int>(t_period * rate);
 
     // create all objects
     Curve curve;
@@ -704,8 +723,8 @@ void PlayBackPlugin::testPlayBack()
 	curve.insert(0.5, 1.0);
     } else {
 	// all above
-	curve.insert(0.5 / (float)tracks, 1.0);
-	curve.insert(1.0 / (float)tracks, 0.0);
+	curve.insert(0.5 / static_cast<float>(tracks), 1.0);
+	curve.insert(1.0 / static_cast<float>(tracks), 0.0);
     }
     curve.insert(1.0, 0.0);
 
@@ -715,12 +734,12 @@ void PlayBackPlugin::testPlayBack()
     for (unsigned int i=0; i < tracks; i++) {
 	Q_ASSERT(delay[i]);
 	if (!delay[i]) break;
-	delay[i]->setAttribute(SLOT(setDelay(const QVariant &)),
+	delay[i]->setAttribute(SLOT(setDelay(const QVariant)),
 	    QVariant(i * t_sweep * rate));
     }
 
     Kwave::Osc osc;
-    osc.setAttribute(SLOT(setFrequency(const QVariant &)),
+    osc.setAttribute(SLOT(setFrequency(const QVariant)),
                      QVariant(rate / freq));
 
     Kwave::MultiTrackSource<Kwave::Mul, true> mul(tracks);
@@ -736,17 +755,17 @@ void PlayBackPlugin::testPlayBack()
     //            osc --'
 
     Kwave::connect(
-	curve_adapter, SIGNAL(output(Kwave::SampleArray &)),
-	delay,         SLOT(input(Kwave::SampleArray &)));
+	curve_adapter, SIGNAL(output(Kwave::SampleArray)),
+	delay,         SLOT(input(Kwave::SampleArray)));
     Kwave::connect(
-	delay,         SIGNAL(output(Kwave::SampleArray &)),
-	mul,           SLOT(input_a(Kwave::SampleArray &)));
+	delay,         SIGNAL(output(Kwave::SampleArray)),
+	mul,           SLOT(input_a(Kwave::SampleArray)));
     Kwave::connect(
-	osc,           SIGNAL(output(Kwave::SampleArray &)),
-	mul,           SLOT(input_b(Kwave::SampleArray &)));
+	osc,           SIGNAL(output(Kwave::SampleArray)),
+	mul,           SLOT(input_b(Kwave::SampleArray)));
     Kwave::connect(
-	mul,           SIGNAL(output(Kwave::SampleArray &)),
-	*sink,         SLOT(input(Kwave::SampleArray &)));
+	mul,           SIGNAL(output(Kwave::SampleArray)),
+	*sink,         SLOT(input(Kwave::SampleArray)));
 
     // show a progress dialog
     QProgressDialog *progress = 0;
@@ -764,14 +783,14 @@ void PlayBackPlugin::testPlayBack()
 		i18n("you should now hear a %1Hz test tone...\n\n"\
 		     "(if you hear clicks or dropouts, "\
 		     "please increase the buffer size "\
-		     "and try again)", (int)freq));
+		     "and try again)", static_cast<int>(freq)));
 	}
     }
 
     // transport the samples
     QTime time;
     time.start();
-    int t_max = periods * (int)t_period * 1000;
+    int t_max = periods * static_cast<int>(t_period) * 1000;
     while ((time.elapsed() < t_max) /*&& (!sink.done())*/) {
 
 	osc.goOn();
