@@ -25,19 +25,21 @@
 
 /**
  * enum for the known recording methods
+ * (sorted, preferred first)
  */
 typedef enum {
     RECORD_NONE = 0, /**< none selected */
-    RECORD_OSS,      /**< OSS native or ALSA OSS emulation */
-    RECORD_ALSA,     /**< ALSA native */
     RECORD_JACK,     /**< Jack sound daemon */
+    RECORD_ALSA,     /**< ALSA native */
+    RECORD_OSS,      /**< OSS native or ALSA OSS emulation */
     RECORD_INVALID   /**< (keep this the last entry, EOL delimiter) */
 } record_method_t;
 
 /** post-increment operator for the record method */
 inline record_method_t &operator ++(record_method_t &m) {
     return (m = (m < RECORD_INVALID) ?
-                (record_method_t)((int)(m) + 1) : m);
+                static_cast<record_method_t>(
+                static_cast<int>(m) + 1) : m);
 }
 
 class RecordParams {
