@@ -29,7 +29,7 @@
 class QStringList;
 
 /** @todo add support for logarithmic scale */
-class VolumePlugin: public KwavePlugin
+class VolumePlugin: public Kwave::Plugin
 {
     Q_OBJECT
 
@@ -43,16 +43,13 @@ public:
 
     /**
      * Shows a dialog for selecting a volume.
-     * @see KwavePlugin::setup
+     * @see Kwave::Plugin::setup
      */
     virtual QStringList *setup(QStringList &previous_params);
 
     /** Does the amplification operation */
     virtual void run(QStringList);
 
-    /** Aborts the process (if running). */
-    virtual int stop();
-
 protected:
 
     /** Reads values from the parameter list */
@@ -68,9 +65,6 @@ private:
     /** mode for amplification selection */
     int m_mode;
 
-    /** flag for stopping the process */
-    bool m_stop;
-
 };
 
 #endif /* _VOLUME_PLUGIN_H_ */
