@@ -33,15 +33,20 @@
 
 KWAVE_PLUGIN(ZeroPlugin,"zero","Thomas Eschenbacher");
 
-#define ZERO_COUNT 64*1024
+#define ZERO_COUNT (64 * 1024)
 
 //***************************************************************************
 ZeroPlugin::ZeroPlugin(const PluginContext &context)
-    :KwavePlugin(context), m_stop(false)
+    :Kwave::Plugin(context), m_zeroes()
 {
      i18n("zero");
 }
 
+//***************************************************************************
+ZeroPlugin::~ZeroPlugin()
+{
+}
+
 //***************************************************************************
 void ZeroPlugin::run(QStringList params)
 {
@@ -49,18 +54,15 @@ void ZeroPlugin::run(QStringList params)
     unsigned int last  = 0;
 
     UndoTransactionGuard undo_guard(*this, i18n("silence"));
-    m_stop = false;
 
     MultiTrackWriter *writers = 0;
 
     /*
      * new mode: insert a range filled with silence:
      * -> usage: zero(<mode>, <range>)
-     * currently the only allowed value for <mode> is "0" (milliseconds)
-     * and <range> must be a number of milliseconds
      */
     if (params.count() == 2) {
-	// get the current selection start
+	// get the current selection
 	selection(&first, &last, false);
 
 	// mode for the time (like in selectrange plugin)
@@ -68,28 +70,25 @@ void ZeroPlugin::run(QStringList params)
 	int mode = params[0].toInt(&ok);
 	Q_ASSERT(ok);
 	if (!ok) return;
-	Q_ASSERT((mode == (int)SelectTimeWidget::byTime) ||
-	         (mode == (int)SelectTimeWidget::bySamples) ||
-	         (mode == (int)SelectTimeWidget::byPercents));
-	switch (mode) {
-	    case (int)SelectTimeWidget::byTime:
-		break;
-	    case (int)SelectTimeWidget::bySamples:
-	    case (int)SelectTimeWidget::byPercents:
-	    default:
-		// for the moment we only support (and need) the
-		// "by time" mode
-		return;
+	Q_ASSERT((mode == static_cast<int>(SelectTimeWidget::byTime)) ||
+	         (mode == static_cast<int>(SelectTimeWidget::bySamples)) ||
+	         (mode == static_cast<int>(SelectTimeWidget::byPercents)));
+	if ((mode != static_cast<int>(SelectTimeWidget::byTime)) &&
+	    (mode != static_cast<int>(SelectTimeWidget::bySamples)) &&
+	    (mode != static_cast<int>(SelectTimeWidget::byPercents)))
+	{
+	    return;
 	}
 
 	// length of the range of zeroes to insert
-	double ms = params[1].toDouble(&ok);
+	unsigned int time = params[1].toUInt(&ok);
 	Q_ASSERT(ok);
 	if (!ok) return;
 
-	// convert from ms to samples
-	double rate = signalRate();
-	unsigned int length = (unsigned int)rint(ms / 1E3 * rate);
+	// convert from time to samples
+	unsigned int length = SelectTimeWidget::timeToSamples(
+	    static_cast<SelectTimeWidget::Mode>(mode),
+	    time, signalRate(), signalLength());
 
 	// get the list of affected tracks
 	QList<unsigned int> tracks = manager().selectedTracks();
@@ -112,6 +111,11 @@ void ZeroPlugin::run(QStringList params)
     // break if aborted
     if (!writers->tracks()) return;
 
+    // connect the progress dialog
+    connect(writers, SIGNAL(progress(unsigned int)),
+	    this,    SLOT(updateProgress(unsigned int)),
+	    Qt::QueuedConnection);
+
     first = (*writers)[0]->first();
     last  = (*writers)[0]->last();
     unsigned int count = writers->tracks();
@@ -124,13 +128,13 @@ void ZeroPlugin::run(QStringList params)
     Q_ASSERT(m_zeroes.size() == ZERO_COUNT);
 
     // loop over the sample range
-    while ((first <= last) && (!m_stop)) {
+    while ((first <= last) && !shouldStop()) {
 	unsigned int rest = last - first + 1;
 	if (rest < m_zeroes.size()) m_zeroes.resize(rest);
 
 	// loop over all writers
 	unsigned int w;
-	for (w=0; w < count; w++) {
+	for (w = 0; w < count; w++) {
 	    *((*writers)[w]) << m_zeroes;
 	}
 
@@ -141,13 +145,6 @@ void ZeroPlugin::run(QStringList params)
     close();
 }
 
-//***************************************************************************
-int ZeroPlugin::stop()
-{
-    m_stop = true;
-    return KwavePlugin::stop();
-}
-
 //***************************************************************************
 #include "ZeroPlugin.moc"
 //***************************************************************************
